@@ -35,6 +35,7 @@ typedef struct {
 	guint64				 flags;
 	GPtrArray			*guids;
 	GPtrArray			*vendor_ids;
+	GPtrArray			*protocols;
 	GPtrArray			*instance_ids;
 	GPtrArray			*icons;
 	gchar				*name;
@@ -161,7 +162,7 @@ fwupd_device_get_summary (FwupdDevice *device)
 /**
  * fwupd_device_set_summary:
  * @device: A #FwupdDevice
- * @summary: the device one line summary
+ * @summary: (nullable): the device one line summary
  *
  * Sets the device summary.
  *
@@ -202,7 +203,7 @@ fwupd_device_get_branch (FwupdDevice *device)
 /**
  * fwupd_device_set_branch:
  * @device: A #FwupdDevice
- * @branch: the device one line branch
+ * @branch: (nullable): the device one line branch
  *
  * Sets the current device branch.
  *
@@ -243,7 +244,7 @@ fwupd_device_get_serial (FwupdDevice *device)
 /**
  * fwupd_device_set_serial:
  * @device: A #FwupdDevice
- * @serial: the device serial number
+ * @serial: (nullable): the device serial number
  *
  * Sets the serial number for the device.
  *
@@ -284,7 +285,7 @@ fwupd_device_get_id (FwupdDevice *device)
 /**
  * fwupd_device_set_id:
  * @device: A #FwupdDevice
- * @id: the device ID, e.g. `USB:foo`
+ * @id: (nullable): the device ID, e.g. `USB:foo`
  *
  * Sets the ID.
  *
@@ -325,7 +326,7 @@ fwupd_device_get_parent_id (FwupdDevice *device)
 /**
  * fwupd_device_set_parent_id:
  * @device: A #FwupdDevice
- * @parent_id: the device ID, e.g. `USB:foo`
+ * @parent_id: (nullable): the device ID, e.g. `USB:foo`
  *
  * Sets the parent ID.
  *
@@ -463,6 +464,7 @@ fwupd_device_has_guid (FwupdDevice *device, const gchar *guid)
 	FwupdDevicePrivate *priv = GET_PRIVATE (device);
 
 	g_return_val_if_fail (FWUPD_IS_DEVICE (device), FALSE);
+	g_return_val_if_fail (guid != NULL, FALSE);
 
 	for (guint i = 0; i < priv->guids->len; i++) {
 		const gchar *guid_tmp = g_ptr_array_index (priv->guids, i);
@@ -486,6 +488,7 @@ fwupd_device_add_guid (FwupdDevice *device, const gchar *guid)
 {
 	FwupdDevicePrivate *priv = GET_PRIVATE (device);
 	g_return_if_fail (FWUPD_IS_DEVICE (device));
+	g_return_if_fail (guid != NULL);
 	if (fwupd_device_has_guid (device, guid))
 		return;
 	g_ptr_array_add (priv->guids, g_strdup (guid));
@@ -546,6 +549,7 @@ fwupd_device_has_instance_id (FwupdDevice *device, const gchar *instance_id)
 	FwupdDevicePrivate *priv = GET_PRIVATE (device);
 
 	g_return_val_if_fail (FWUPD_IS_DEVICE (device), FALSE);
+	g_return_val_if_fail (instance_id != NULL, FALSE);
 
 	for (guint i = 0; i < priv->instance_ids->len; i++) {
 		const gchar *instance_id_tmp = g_ptr_array_index (priv->instance_ids, i);
@@ -569,6 +573,7 @@ fwupd_device_add_instance_id (FwupdDevice *device, const gchar *instance_id)
 {
 	FwupdDevicePrivate *priv = GET_PRIVATE (device);
 	g_return_if_fail (FWUPD_IS_DEVICE (device));
+	g_return_if_fail (instance_id != NULL);
 	if (fwupd_device_has_instance_id (device, instance_id))
 		return;
 	g_ptr_array_add (priv->instance_ids, g_strdup (instance_id));
@@ -621,6 +626,7 @@ fwupd_device_add_icon (FwupdDevice *device, const gchar *icon)
 {
 	FwupdDevicePrivate *priv = GET_PRIVATE (device);
 	g_return_if_fail (FWUPD_IS_DEVICE (device));
+	g_return_if_fail (icon != NULL);
 	if (fwupd_device_has_icon (device, icon))
 		return;
 	g_ptr_array_add (priv->icons, g_strdup (icon));
@@ -647,7 +653,7 @@ fwupd_device_get_name (FwupdDevice *device)
 /**
  * fwupd_device_set_name:
  * @device: A #FwupdDevice
- * @name: the device name, e.g. `ColorHug2`
+ * @name: (nullable): the device name, e.g. `ColorHug2`
  *
  * Sets the device name.
  *
@@ -688,7 +694,7 @@ fwupd_device_get_vendor (FwupdDevice *device)
 /**
  * fwupd_device_set_vendor:
  * @device: A #FwupdDevice
- * @vendor: the description
+ * @vendor: (nullable): the description
  *
  * Sets the device vendor.
  *
@@ -851,7 +857,7 @@ fwupd_device_get_description (FwupdDevice *device)
 /**
  * fwupd_device_set_description:
  * @device: A #FwupdDevice
- * @description: the description in AppStream markup format
+ * @description: (nullable): the description in AppStream markup format
  *
  * Sets the device description.
  *
@@ -892,7 +898,7 @@ fwupd_device_get_version (FwupdDevice *device)
 /**
  * fwupd_device_set_version:
  * @device: A #FwupdDevice
- * @version: the device version, e.g. `1.2.3`
+ * @version: (nullable): the device version, e.g. `1.2.3`
  *
  * Sets the device version.
  *
@@ -933,7 +939,7 @@ fwupd_device_get_version_lowest (FwupdDevice *device)
 /**
  * fwupd_device_set_version_lowest:
  * @device: A #FwupdDevice
- * @version_lowest: the description
+ * @version_lowest: (nullable): the version
  *
  * Sets the lowest version of firmware the device will accept.
  *
@@ -1009,7 +1015,7 @@ fwupd_device_get_version_bootloader (FwupdDevice *device)
 /**
  * fwupd_device_set_version_bootloader:
  * @device: A #FwupdDevice
- * @version_bootloader: the description
+ * @version_bootloader: (nullable): the version
  *
  * Sets the bootloader version.
  *
@@ -1155,7 +1161,7 @@ fwupd_device_get_plugin (FwupdDevice *device)
 /**
  * fwupd_device_set_plugin:
  * @device: A #FwupdDevice
- * @plugin: the plugin name, e.g. `colorhug`
+ * @plugin: (nullable): the plugin name, e.g. `colorhug`
  *
  * Sets the plugin that created the device.
  *
@@ -1184,6 +1190,8 @@ fwupd_device_set_plugin (FwupdDevice *device, const gchar *plugin)
  * Returns: the protocol name, or %NULL if unset
  *
  * Since: 1.3.6
+ *
+ * Deprecated: 1.5.8: Use fwupd_device_get_protocols() instead.
  **/
 const gchar *
 fwupd_device_get_protocol (FwupdDevice *device)
@@ -1201,19 +1209,98 @@ fwupd_device_get_protocol (FwupdDevice *device)
  * Sets the protocol that is used to update the device.
  *
  * Since: 1.3.6
+ *
+ * Deprecated: 1.5.8: Use fwupd_device_add_protocol() instead.
  **/
 void
 fwupd_device_set_protocol (FwupdDevice *device, const gchar *protocol)
 {
-	FwupdDevicePrivate *priv = GET_PRIVATE (device);
+	g_auto(GStrv) protocols = NULL;
+
 	g_return_if_fail (FWUPD_IS_DEVICE (device));
+	g_return_if_fail (protocol != NULL);
 
-	/* not changed */
-	if (g_strcmp0 (priv->protocol, protocol) == 0)
+	/* add all */
+	protocols = g_strsplit (protocol, "|", -1);
+	for (guint i = 0; protocols[i] != NULL; i++)
+		fwupd_device_add_protocol (device, protocols[i]);
+}
+
+/**
+ * fwupd_device_get_protocols:
+ * @device: A #FwupdDevice
+ *
+ * Gets the device protocol.
+ *
+ * Returns: (element-type utf8) (transfer none): the device protocol
+ *
+ * Since: 1.5.8
+ **/
+GPtrArray *
+fwupd_device_get_protocols (FwupdDevice *device)
+{
+	FwupdDevicePrivate *priv = GET_PRIVATE (device);
+	g_return_val_if_fail (FWUPD_IS_DEVICE (device), NULL);
+	return priv->protocols;
+}
+
+/**
+ * fwupd_device_has_protocol:
+ * @device: A #FwupdDevice
+ * @protocol: the ID, e.g. 'USB:0x1234'
+ *
+ * Finds out if the device has this specific protocol.
+ *
+ * Returns: %TRUE if the ID is found
+ *
+ * Since: 1.5.8
+ **/
+gboolean
+fwupd_device_has_protocol (FwupdDevice *device, const gchar *protocol)
+{
+	FwupdDevicePrivate *priv = GET_PRIVATE (device);
+
+	g_return_val_if_fail (FWUPD_IS_DEVICE (device), FALSE);
+	g_return_val_if_fail (protocol != NULL, FALSE);
+
+	for (guint i = 0; i < priv->protocols->len; i++) {
+		const gchar *protocol_tmp = g_ptr_array_index (priv->protocols, i);
+		if (g_strcmp0 (protocol, protocol_tmp) == 0)
+			return TRUE;
+	}
+	return FALSE;
+}
+
+/**
+ * fwupd_device_add_protocol:
+ * @device: A #FwupdDevice
+ * @protocol: the ID, e.g. 'USB:0x1234'
+ *
+ * Adds a device protocol.
+ *
+ * Since: 1.5.8
+ **/
+void
+fwupd_device_add_protocol (FwupdDevice *device, const gchar *protocol)
+{
+	FwupdDevicePrivate *priv = GET_PRIVATE (device);
+	g_auto(GStrv) protocols_tmp = NULL;
+
+	g_return_if_fail (FWUPD_IS_DEVICE (device));
+	g_return_if_fail (protocol != NULL);
+
+	if (fwupd_device_has_protocol (device, protocol))
 		return;
+	g_ptr_array_add (priv->protocols, g_strdup (protocol));
 
+	/* build for compatibility */
+	protocols_tmp = g_new0 (gchar *, priv->protocols->len + 1);
+	for (guint i = 0; i < priv->protocols->len; i++) {
+		const gchar *protocol_tmp = g_ptr_array_index (priv->protocols, i);
+		protocols_tmp[i] = g_strdup (protocol_tmp);
+	}
 	g_free (priv->protocol);
-	priv->protocol = g_strdup (protocol);
+	priv->protocol = g_strjoinv ("|", protocols_tmp);
 }
 
 /**
@@ -1435,8 +1522,10 @@ fwupd_device_incorporate (FwupdDevice *self, FwupdDevice *donor)
 	}
 	if (priv->plugin == NULL)
 		fwupd_device_set_plugin (self, priv_donor->plugin);
-	if (priv->protocol == NULL)
-		fwupd_device_set_protocol (self, priv_donor->protocol);
+	for (guint i = 0; i < priv_donor->protocols->len; i++) {
+		const gchar *tmp = g_ptr_array_index (priv_donor->protocols, i);
+		fwupd_device_add_protocol (self, tmp);
+	}
 	if (priv->update_error == NULL)
 		fwupd_device_set_update_error (self, priv_donor->update_error);
 	if (priv->update_message == NULL)
@@ -1593,10 +1682,17 @@ fwupd_device_to_variant_full (FwupdDevice *device, FwupdDeviceFlags flags)
 				       FWUPD_RESULT_KEY_PLUGIN,
 				       g_variant_new_string (priv->plugin));
 	}
-	if (priv->protocol != NULL) {
+	if (priv->protocols->len > 0) {
+		g_autoptr(GString) str = g_string_new (NULL);
+		for (guint i = 0; i < priv->protocols->len; i++) {
+			const gchar *tmp = g_ptr_array_index (priv->protocols, i);
+			g_string_append_printf (str, "%s|", tmp);
+		}
+		if (str->len > 0)
+			g_string_truncate (str, str->len - 1);
 		g_variant_builder_add (&builder, "{sv}",
 				       FWUPD_RESULT_KEY_PROTOCOL,
-				       g_variant_new_string (priv->protocol));
+				       g_variant_new_string (str->str));
 	}
 	if (priv->version != NULL) {
 		g_variant_builder_add (&builder, "{sv}",
@@ -1813,7 +1909,10 @@ fwupd_device_from_key_value (FwupdDevice *device, const gchar *key, GVariant *va
 		return;
 	}
 	if (g_strcmp0 (key, FWUPD_RESULT_KEY_PROTOCOL) == 0) {
-		fwupd_device_set_protocol (device, g_variant_get_string (value, NULL));
+		g_auto(GStrv) protocols = NULL;
+		protocols = g_strsplit (g_variant_get_string (value, NULL), "|", -1);
+		for (guint i = 0; protocols[i] != NULL; i++)
+			fwupd_device_add_protocol (device, protocols[i]);
 		return;
 	}
 	if (g_strcmp0 (key, FWUPD_RESULT_KEY_VERSION) == 0) {
@@ -2060,7 +2159,7 @@ fwupd_device_get_update_message (FwupdDevice *device)
 /**
  * fwupd_device_set_update_message:
  * @device: A #FwupdDevice
- * @update_message: the update message string
+ * @update_message: (nullable): the update message string
  *
  * Sets the update message.
  *
@@ -2101,7 +2200,7 @@ fwupd_device_get_update_image (FwupdDevice *device)
 /**
  * fwupd_device_set_update_image:
  * @device: A #FwupdDevice
- * @update_image: the update image URL
+ * @update_image: (nullable): the update image URL
  *
  * Sets the update image.
  *
@@ -2142,7 +2241,7 @@ fwupd_device_get_update_error (FwupdDevice *device)
 /**
  * fwupd_device_set_update_error:
  * @device: A #FwupdDevice
- * @update_error: the update error string
+ * @update_error: (nullable): the update error string
  *
  * Sets the update error.
  *
@@ -2316,6 +2415,15 @@ fwupd_device_to_json (FwupdDevice *device, JsonBuilder *builder)
 	fwupd_device_json_add_string (builder, FWUPD_RESULT_KEY_BRANCH, priv->branch);
 	fwupd_device_json_add_string (builder, FWUPD_RESULT_KEY_PLUGIN, priv->plugin);
 	fwupd_device_json_add_string (builder, FWUPD_RESULT_KEY_PROTOCOL, priv->protocol);
+	if (priv->protocols->len > 1) { /* --> 0 when bumping API */
+		json_builder_set_member_name (builder, "VendorIds");
+		json_builder_begin_array (builder);
+		for (guint i = 0; i < priv->protocols->len; i++) {
+			const gchar *tmp = g_ptr_array_index (priv->protocols, i);
+			json_builder_add_string_value (builder, tmp);
+		}
+		json_builder_end_array (builder);
+	}
 	if (priv->flags != FWUPD_DEVICE_FLAG_NONE) {
 		json_builder_set_member_name (builder, FWUPD_RESULT_KEY_FLAGS);
 		json_builder_begin_array (builder);
@@ -2461,7 +2569,10 @@ fwupd_device_to_string (FwupdDevice *device)
 	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_DESCRIPTION, priv->description);
 	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_BRANCH, priv->branch);
 	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_PLUGIN, priv->plugin);
-	fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_PROTOCOL, priv->protocol);
+	for (guint i = 0; i < priv->protocols->len; i++) {
+		const gchar *tmp = g_ptr_array_index (priv->protocols, i);
+		fwupd_pad_kv_str (str, FWUPD_RESULT_KEY_PROTOCOL, tmp);
+	}
 	fwupd_pad_kv_dfl (str, FWUPD_RESULT_KEY_FLAGS, priv->flags);
 	for (guint i = 0; i < priv->checksums->len; i++) {
 		const gchar *checksum = g_ptr_array_index (priv->checksums, i);
@@ -2563,7 +2674,7 @@ fwupd_device_set_property (GObject *object, guint prop_id,
 		fwupd_device_set_flags (self, g_value_get_uint64 (value));
 		break;
 	case PROP_PROTOCOL:
-		fwupd_device_set_protocol (self, g_value_get_string (value));
+		fwupd_device_add_protocol (self, g_value_get_string (value));
 		break;
 	case PROP_STATUS:
 		fwupd_device_set_status (self, g_value_get_uint (value));
@@ -2644,6 +2755,7 @@ fwupd_device_init (FwupdDevice *device)
 	priv->icons = g_ptr_array_new_with_free_func (g_free);
 	priv->checksums = g_ptr_array_new_with_free_func (g_free);
 	priv->vendor_ids = g_ptr_array_new_with_free_func (g_free);
+	priv->protocols = g_ptr_array_new_with_free_func (g_free);
 	priv->children = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	priv->releases = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 }
@@ -2682,6 +2794,7 @@ fwupd_device_finalize (GObject *object)
 	g_free (priv->version_bootloader);
 	g_ptr_array_unref (priv->guids);
 	g_ptr_array_unref (priv->vendor_ids);
+	g_ptr_array_unref (priv->protocols);
 	g_ptr_array_unref (priv->instance_ids);
 	g_ptr_array_unref (priv->icons);
 	g_ptr_array_unref (priv->checksums);
