@@ -1403,15 +1403,14 @@ fu_common_string_append_kv (GString *str, guint idt, const gchar *key, const gch
 				for (gsize j = keysz; j < align; j++)
 					g_string_append (str, " ");
 			} else {
+				g_string_append (str, "\n");
 				for (gsize j = 0; j < idt; j++)
 					g_string_append (str, "  ");
 			}
 			g_string_append (str, split[i]);
-			g_string_append (str, "\n");
 		}
-	} else {
-		g_string_append (str, "\n");
 	}
+	g_string_append (str, "\n");
 }
 
 /**
@@ -2698,7 +2697,7 @@ fu_common_get_memory_size (void)
 	GlobalMemoryStatusEx (&status);
 	return (guint64) status.ullTotalPhys;
 #else
-	return sysconf (_SC_PHYS_PAGES) * sysconf (_SC_PAGE_SIZE);
+	return (guint64) sysconf (_SC_PHYS_PAGES) * (guint64) sysconf (_SC_PAGE_SIZE);
 #endif
 }
 
@@ -2729,16 +2728,16 @@ fu_common_get_block_devices (GError **error)
 		return NULL;
 	}
 	g_variant_builder_init (&builder, G_VARIANT_TYPE_VARDICT);
-	output =  g_dbus_proxy_call_sync (proxy,
-					  "GetBlockDevices",
-					  g_variant_new ("(a{sv})", &builder),
-					  G_DBUS_CALL_FLAGS_NONE,
-					  -1, NULL, error);
+	output = g_dbus_proxy_call_sync (proxy,
+					 "GetBlockDevices",
+					 g_variant_new ("(a{sv})", &builder),
+					 G_DBUS_CALL_FLAGS_NONE,
+					 -1, NULL, error);
 	if (output == NULL) {
 		if (error != NULL)
 			g_dbus_error_strip_remote_error (*error);
 		g_prefix_error (error, "failed to call %s.%s(): ",
-				UDISKS_DBUS_SERVICE,
+				UDISKS_DBUS_MANAGER_INTERFACE,
 				"GetBlockDevices");
 		return NULL;
 	}
@@ -2759,7 +2758,6 @@ fu_common_get_block_devices (GError **error)
 		g_ptr_array_add (devices, g_steal_pointer (&proxy_blk));
 	}
 
-
 	return g_steal_pointer (&devices);
 }
 
