@@ -229,6 +229,23 @@ fu_ihex_firmware_parse (FuFirmware *firmware,
 		/* process different record types */
 		switch (rcd->record_type) {
 		case FU_IHEX_FIRMWARE_RECORD_TYPE_DATA:
+
+			/* does not make sense */
+			if (got_eof) {
+				g_set_error_literal (error,
+						     FWUPD_ERROR,
+						     FWUPD_ERROR_INVALID_FILE,
+						     "cannot process data after EOF");
+				return FALSE;
+			}
+			if (rcd->data->len == 0) {
+				g_set_error_literal (error,
+						     FWUPD_ERROR,
+						     FWUPD_ERROR_INVALID_FILE,
+						     "cannot parse invalid data");
+				return FALSE;
+			}
+
 			/* base address for element */
 			if (img_addr == G_MAXUINT32)
 				img_addr = addr;
@@ -266,6 +283,14 @@ fu_ihex_firmware_parse (FuFirmware *firmware,
 				}
 			}
 			addr_last = addr + rcd->data->len - 1;
+			if (addr_last < addr) {
+				g_set_error (error,
+					     FWUPD_ERROR,
+					     FWUPD_ERROR_INVALID_FILE,
+					     "overflow of address 0x%x on line %u",
+					     (guint) addr, rcd->ln);
+				return FALSE;
+			}
 
 			/* write into buf */
 			g_byte_array_append (buf, rcd->data->data, rcd->data->len);
