@@ -582,21 +582,26 @@ fu_plugin_quirks_device_func (void)
 static void fu_common_kernel_lockdown_func (void)
 {
 	gboolean ret;
-	g_autofree gchar *old_kernel_dir = g_build_filename (TESTDATADIR_SRC,
-							     "lockdown", NULL);
-	g_autofree gchar *locked_dir = g_build_filename (TESTDATADIR_SRC,
-							 "lockdown", "locked", NULL);
-	g_autofree gchar *none_dir = g_build_filename (TESTDATADIR_SRC,
-							"lockedown", "none", NULL);
+	g_autofree gchar *locked_dir = NULL;
+	g_autofree gchar *none_dir = NULL;
+	g_autofree gchar *old_kernel_dir = NULL;
 
+#ifndef __linux__
+	g_test_skip ("only works on Linux");
+	return;
+#endif
+
+	old_kernel_dir = g_build_filename (TESTDATADIR_SRC, "lockdown", NULL);
 	g_setenv ("FWUPD_SYSFSSECURITYDIR", old_kernel_dir, TRUE);
 	ret = fu_common_kernel_locked_down ();
 	g_assert_false (ret);
 
+	locked_dir = g_build_filename (TESTDATADIR_SRC, "lockdown", "locked", NULL);
 	g_setenv ("FWUPD_SYSFSSECURITYDIR", locked_dir, TRUE);
 	ret = fu_common_kernel_locked_down ();
 	g_assert_true (ret);
 
+	none_dir = g_build_filename (TESTDATADIR_SRC, "lockdown", "none", NULL);
 	g_setenv ("FWUPD_SYSFSSECURITYDIR", none_dir, TRUE);
 	ret = fu_common_kernel_locked_down ();
 	g_assert_false (ret);
@@ -679,17 +684,19 @@ fu_device_locker_func (void)
 }
 
 static gboolean
-_fail_open_cb (GObject *device, GError **error)
+_fail_open_cb (FuDevice *device, GError **error)
 {
+	fu_device_set_metadata_boolean (device, "Test::Open", TRUE);
 	g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED, "fail");
 	return FALSE;
 }
 
 static gboolean
-_fail_close_cb (GObject *device, GError **error)
+_fail_close_cb (FuDevice *device, GError **error)
 {
-	g_assert_not_reached ();
-	return TRUE;
+	fu_device_set_metadata_boolean (device, "Test::Close", TRUE);
+	g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_BUSY, "busy");
+	return FALSE;
 }
 
 static void
@@ -697,10 +704,16 @@ fu_device_locker_fail_func (void)
 {
 	g_autoptr(FuDeviceLocker) locker = NULL;
 	g_autoptr(GError) error = NULL;
-	g_autoptr(GObject) device = g_object_new (G_TYPE_OBJECT, NULL);
-	locker = fu_device_locker_new_full (device, _fail_open_cb, _fail_close_cb, &error);
+	g_autoptr(FuDevice) device = fu_device_new ();
+	locker = fu_device_locker_new_full (device,
+					    (FuDeviceLockerFunc) _fail_open_cb,
+					    (FuDeviceLockerFunc) _fail_close_cb,
+					    &error);
 	g_assert_error (error, G_IO_ERROR, G_IO_ERROR_FAILED);
 	g_assert_null (locker);
+	g_assert_true (fu_device_get_metadata_boolean (device, "Test::Open"));
+	g_assert_true (fu_device_get_metadata_boolean (device, "Test::Close"));
+	g_assert_false (fu_device_has_internal_flag (device, FU_DEVICE_INTERNAL_FLAG_IS_OPEN));
 }
 
 static void
@@ -943,6 +956,31 @@ fu_common_store_cab_unsigned_func (void)
 	g_assert_nonnull (blob_tmp);
 }
 
+static void
+fu_common_store_cab_sha256_func (void)
+{
+	g_autoptr(GBytes) blob = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(XbSilo) silo = NULL;
+
+	/* create silo */
+	blob = _build_cab (GCAB_COMPRESSION_NONE,
+			   "acme.metainfo.xml",
+	"<component type=\"firmware\">\n"
+	"  <id>com.acme.example.firmware</id>\n"
+	"  <releases>\n"
+	"    <release version=\"1.2.3\" date=\"2017-09-06\">\n"
+	"      <checksum target=\"content\" type=\"sha256\">486ea46224d1bb4fb680f34f7c9ad96a8f24ec88be73ea8e5a6c65260e9cb8a7</checksum>\n"
+	"    </release>\n"
+	"  </releases>\n"
+	"</component>",
+			   "firmware.bin", "world",
+			   NULL);
+	silo = fu_common_cab_build_silo (blob, 10240, &error);
+	g_assert_no_error (error);
+	g_assert_nonnull (silo);
+}
+
 static void
 fu_common_store_cab_folder_func (void)
 {
@@ -1971,6 +2009,11 @@ fu_firmware_fmap_func (void)
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GPtrArray) images = NULL;
 
+#ifndef HAVE_MEMMEM
+	g_test_skip ("no memmem()");
+	return;
+#endif
+
 	/* load firmware */
 	filename = g_build_filename (TESTDATADIR_SRC, "firmware.fmap", NULL);
 	g_assert (filename != NULL);
@@ -2208,6 +2251,11 @@ fu_efivar_func (void)
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GPtrArray) names = NULL;
 
+#ifndef __linux__
+	g_test_skip ("only works on Linux");
+	return;
+#endif
+
 	/* check supported */
 	ret = fu_efivar_supported (&error);
 	g_assert_no_error (error);
@@ -2492,6 +2540,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/fwupd/common{cab-success}", fu_common_store_cab_func);
 	g_test_add_func ("/fwupd/common{cab-success-unsigned}", fu_common_store_cab_unsigned_func);
 	g_test_add_func ("/fwupd/common{cab-success-folder}", fu_common_store_cab_folder_func);
+	g_test_add_func ("/fwupd/common{cab-success-sha256}", fu_common_store_cab_sha256_func);
 	g_test_add_func ("/fwupd/common{cab-error-no-metadata}", fu_common_store_cab_error_no_metadata_func);
 	g_test_add_func ("/fwupd/common{cab-error-wrong-size}", fu_common_store_cab_error_wrong_size_func);
 	g_test_add_func ("/fwupd/common{cab-error-wrong-checksum}", fu_common_store_cab_error_wrong_checksum_func);
