@@ -238,10 +238,11 @@ fu_srec_firmware_tokenize (FuFirmware *firmware, GBytes *fw,
 		default:
 			g_assert_not_reached ();
 		}
-
-		g_debug ("line %03u S%u addr:0x%04x datalen:0x%02x",
-			 ln + 1, rec_kind, rec_addr32,
-			 (guint) rec_count - addrsz - 1);
+		if (g_getenv ("FU_SREC_FIRMWARE_VERBOSE") != NULL) {
+			g_debug ("line %03u S%u addr:0x%04x datalen:0x%02x",
+				 ln + 1, rec_kind, rec_addr32,
+				 (guint) rec_count - addrsz - 1);
+		}
 
 		/* data */
 		rcd = fu_srec_firmware_record_new (ln + 1, rec_kind, rec_addr32);
@@ -380,6 +381,14 @@ fu_srec_firmware_parse (FuFirmware *firmware,
 				if (img_address == 0x0)
 					img_address = rcd->addr;
 				addr32_last = rcd->addr + rcd->buf->len;
+				if (addr32_last < rcd->addr) {
+					g_set_error (error,
+						     FWUPD_ERROR,
+						     FWUPD_ERROR_INVALID_FILE,
+						     "overflow from address 0x%x at line %u",
+						     (guint) rcd->addr, rcd->ln);
+					return FALSE;
+				}
 			}
 			data_cnt++;
 		}
