@@ -564,6 +564,9 @@ fu_udev_device_set_dev (FuUdevDevice *self, GUdevDevice *udev_device)
 	fu_udev_device_set_driver (self, g_udev_device_get_driver (priv->udev_device));
 	fu_udev_device_set_device_file (self, g_udev_device_get_device_file (priv->udev_device));
 
+	/* so we can display something sensible for unclaimed devices */
+	fu_device_set_backend_id (FU_DEVICE (self), g_udev_device_get_sysfs_path (priv->udev_device));
+
 	/* fall back to the first thing handled by misc drivers */
 	if (priv->device_file == NULL) {
 		/* perhaps we should unconditionally fall back? or perhaps
@@ -1105,6 +1108,85 @@ fu_udev_device_set_physical_id (FuUdevDevice *self, const gchar *subsystems, GEr
 #endif
 }
 
+/**
+ * fu_udev_device_set_logical_id:
+ * @self: A #FuUdevDevice
+ * @subsystem: A subsystem string, e.g. `pci,usb`
+ * @error: A #GError, or %NULL
+ *
+ * Sets the logical ID from the device subsystem. Plugins should choose the
+ * subsystem that most relevant in the udev tree, for instance choosing 'hid'
+ * over 'usb' for a mouse device.
+ *
+ * Returns: %TRUE if the logical device was set.
+ *
+ * Since: 1.5.8
+ **/
+gboolean
+fu_udev_device_set_logical_id (FuUdevDevice *self, const gchar *subsystem, GError **error)
+{
+#ifdef HAVE_GUDEV
+	FuUdevDevicePrivate *priv = GET_PRIVATE (self);
+	const gchar *tmp;
+	g_autofree gchar *logical_id = NULL;
+	g_autoptr(GUdevDevice) udev_device = NULL;
+
+	g_return_val_if_fail (FU_IS_UDEV_DEVICE (self), FALSE);
+	g_return_val_if_fail (subsystem != NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	/* nothing to do */
+	if (priv->udev_device == NULL)
+		return TRUE;
+
+	/* find correct device matching subsystem */
+	if (g_strcmp0 (priv->subsystem, subsystem) == 0) {
+		udev_device = g_object_ref (priv->udev_device);
+	} else {
+		udev_device = g_udev_device_get_parent_with_subsystem (priv->udev_device,
+								       subsystem, NULL);
+	}
+	if (udev_device == NULL) {
+		g_set_error (error,
+			     G_IO_ERROR,
+			     G_IO_ERROR_NOT_FOUND,
+			     "failed to find device with subsystem %s",
+			     subsystem);
+		return FALSE;
+	}
+
+	/* query each subsystem */
+	if (g_strcmp0 (subsystem, "hid") == 0) {
+		tmp = g_udev_device_get_property (udev_device, "HID_UNIQ");
+		if (tmp == NULL) {
+			g_set_error_literal (error,
+					     G_IO_ERROR,
+					     G_IO_ERROR_NOT_FOUND,
+					     "failed to find HID_UNIQ");
+			return FALSE;
+		}
+		logical_id = g_strdup_printf ("HID_UNIQ=%s", tmp);
+	} else {
+		g_set_error (error,
+			     G_IO_ERROR,
+			     G_IO_ERROR_NOT_SUPPORTED,
+			     "cannot handle subsystem %s",
+			     subsystem);
+		return FALSE;
+	}
+
+	/* success */
+	fu_device_set_logical_id (FU_DEVICE (self), logical_id);
+	return TRUE;
+#else
+	g_set_error_literal (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_NOT_SUPPORTED,
+			     "Not supported as <gudev.h> is unavailable");
+	return FALSE;
+#endif
+}
+
 /**
  * fu_udev_device_get_fd:
  * @self: A #FuUdevDevice
@@ -1325,9 +1407,19 @@ fu_udev_device_ioctl (FuUdevDevice *self,
 	g_return_val_if_fail (FU_IS_UDEV_DEVICE (self), FALSE);
 	g_return_val_if_fail (request != 0x0, FALSE);
 	g_return_val_if_fail (buf != NULL, FALSE);
-	g_return_val_if_fail (priv->fd > 0, FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
+	/* not open! */
+	if (priv->fd == 0) {
+		g_set_error (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_INTERNAL,
+			     "%s [%s] has not been opened",
+			     fu_device_get_id (FU_DEVICE (self)),
+			     fu_device_get_name (FU_DEVICE (self)));
+		return FALSE;
+	}
+
 	rc_tmp = ioctl (priv->fd, request, buf);
 	if (rc != NULL)
 		*rc = rc_tmp;
@@ -1386,9 +1478,19 @@ fu_udev_device_pread_full (FuUdevDevice *self, goffset port,
 
 	g_return_val_if_fail (FU_IS_UDEV_DEVICE (self), FALSE);
 	g_return_val_if_fail (buf != NULL, FALSE);
-	g_return_val_if_fail (priv->fd > 0, FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
+	/* not open! */
+	if (priv->fd == 0) {
+		g_set_error (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_INTERNAL,
+			     "%s [%s] has not been opened",
+			     fu_device_get_id (FU_DEVICE (self)),
+			     fu_device_get_name (FU_DEVICE (self)));
+		return FALSE;
+	}
+
 #ifdef HAVE_PWRITE
 	if (pread (priv->fd, buf, bufsz, port) != (gssize) bufsz) {
 		g_set_error (error,
@@ -1431,9 +1533,19 @@ fu_udev_device_pwrite_full (FuUdevDevice *self, goffset port,
 	FuUdevDevicePrivate *priv = GET_PRIVATE (self);
 
 	g_return_val_if_fail (FU_IS_UDEV_DEVICE (self), FALSE);
-	g_return_val_if_fail (priv->fd > 0, FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
+	/* not open! */
+	if (priv->fd == 0) {
+		g_set_error (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_INTERNAL,
+			     "%s [%s] has not been opened",
+			     fu_device_get_id (FU_DEVICE (self)),
+			     fu_device_get_name (FU_DEVICE (self)));
+		return FALSE;
+	}
+
 #ifdef HAVE_PWRITE
 	if (pwrite (priv->fd, buf, bufsz, port) != (gssize) bufsz) {
 		g_set_error (error,
