@@ -144,7 +144,7 @@ fu_dell_dock_status_finalize (GObject *object)
 static void
 fu_dell_dock_status_init (FuDellDockStatus *self)
 {
-	fu_device_set_protocol (FU_DEVICE (self), "com.dell.dock");
+	fu_device_add_protocol (FU_DEVICE (self), "com.dell.dock");
 }
 
 static void
