@@ -35,7 +35,7 @@
  * * `ignore-polltimeout`:	Ignore the device download timeout
  * * `ignore-runtime`:		Device has broken DFU runtime support
  * * `ignore-upload`:		Uploading from the device is broken
- * * `no-fu-dfu-runtime`:		No DFU runtime interface is provided
+ * * `no-dfu-runtime`:		No DFU runtime interface is provided
  * * `no-get-status-upload`:	Do not do GetStatus when uploading
  * * `no-pid-change`:		Accept the same VID:PID when changing modes
  * * `use-any-interface`:	Use any interface for DFU
@@ -402,7 +402,7 @@ fu_dfu_device_add_targets (FuDfuDevice *self, GError **error)
 
 	/* the device has no DFU runtime, so cheat */
 	if (priv->targets->len == 0 &&
-	    fu_device_has_custom_flag (FU_DEVICE (self), "no-fu-dfu-runtime")) {
+	    fu_device_has_custom_flag (FU_DEVICE (self), "no-dfu-runtime")) {
 		g_debug ("no DFU runtime, so faking device");
 		fu_dfu_device_set_state (self, FU_DFU_STATE_APP_IDLE);
 		priv->iface_number = 0xff;
@@ -871,7 +871,7 @@ fu_dfu_device_refresh (FuDfuDevice *self, GError **error)
 
 	/* the device has no DFU runtime, so cheat */
 	if (priv->state == FU_DFU_STATE_APP_IDLE &&
-	    fu_device_has_custom_flag (FU_DEVICE (self), "no-fu-dfu-runtime"))
+	    fu_device_has_custom_flag (FU_DEVICE (self), "no-dfu-runtime"))
 		return TRUE;
 
 	/* ensure interface is claimed */
@@ -1019,7 +1019,7 @@ fu_dfu_device_detach (FuDevice *device, GError **error)
 
 	/* the device has no DFU runtime, so cheat */
 	if (priv->state == FU_DFU_STATE_APP_IDLE &&
-	    fu_device_has_custom_flag (FU_DEVICE (self), "no-fu-dfu-runtime"))
+	    fu_device_has_custom_flag (FU_DEVICE (self), "no-dfu-runtime"))
 		return TRUE;
 
 	/* ensure interface is claimed */
@@ -1076,7 +1076,7 @@ fu_dfu_device_abort (FuDfuDevice *self, GError **error)
 
 	/* the device has no DFU runtime, so cheat */
 	if (priv->state == FU_DFU_STATE_APP_IDLE &&
-	    fu_device_has_custom_flag (FU_DEVICE (self), "no-fu-dfu-runtime")) {
+	    fu_device_has_custom_flag (FU_DEVICE (self), "no-dfu-runtime")) {
 		g_set_error_literal (error,
 				     FWUPD_ERROR,
 				     FWUPD_ERROR_NOT_SUPPORTED,
@@ -1143,7 +1143,7 @@ fu_dfu_device_clear_status (FuDfuDevice *self, GError **error)
 
 	/* the device has no DFU runtime, so cheat */
 	if (priv->state == FU_DFU_STATE_APP_IDLE &&
-	    fu_device_has_custom_flag (FU_DEVICE (self), "no-fu-dfu-runtime")) {
+	    fu_device_has_custom_flag (FU_DEVICE (self), "no-dfu-runtime")) {
 		g_set_error_literal (error,
 				     FWUPD_ERROR,
 				     FWUPD_ERROR_NOT_SUPPORTED,
@@ -1217,7 +1217,7 @@ fu_dfu_device_open (FuDevice *device, GError **error)
 
 	/* the device has no DFU runtime, so cheat */
 	if (priv->state == FU_DFU_STATE_APP_IDLE &&
-	    fu_device_has_custom_flag (device, "no-fu-dfu-runtime")) {
+	    fu_device_has_custom_flag (device, "no-dfu-runtime")) {
 		fu_dfu_device_set_state (self, FU_DFU_STATE_APP_IDLE);
 		priv->status = FU_DFU_STATUS_OK;
 	}
@@ -1302,8 +1302,12 @@ fu_dfu_device_close (FuDevice *device, GError **error)
 		if (!g_usb_device_release_interface (usb_device,
 						     (gint) priv->iface_number,
 						     0, &error_local)) {
-			g_warning ("failed to release interface: %s",
-				   error_local->message);
+			if (!g_error_matches (error_local,
+					      G_USB_DEVICE_ERROR,
+					      G_USB_DEVICE_ERROR_NO_DEVICE)) {
+				g_warning ("failed to release interface: %s",
+					   error_local->message);
+			}
 		}
 		priv->claimed_interface = FALSE;
 	}
@@ -1593,6 +1597,9 @@ fu_dfu_device_download (FuDfuDevice *self,
 	if (FU_IS_DFU_FIRMWARE (firmware)) {
 		firmware_vid = fu_dfu_firmware_get_vid (FU_DFU_FIRMWARE (firmware));
 		firmware_pid = fu_dfu_firmware_get_pid (FU_DFU_FIRMWARE (firmware));
+	} else {
+		flags |= DFU_TARGET_TRANSFER_FLAG_WILDCARD_VID;
+		flags |= DFU_TARGET_TRANSFER_FLAG_WILDCARD_PID;
 	}
 
 	/* do we allow wildcard VID:PID matches */
@@ -1649,13 +1656,8 @@ fu_dfu_device_download (FuDfuDevice *self,
 
 	/* download each target */
 	images = fu_firmware_get_images (firmware);
-	if (images->len == 0) {
-		g_set_error_literal (error,
-				     FWUPD_ERROR,
-				     FWUPD_ERROR_INVALID_FILE,
-				     "no images in firmware file");
-		return FALSE;
-	}
+	if (images->len == 0)
+		g_ptr_array_add (images, g_object_ref (firmware));
 	for (guint i = 0; i < images->len; i++) {
 		FuFirmwareImage *image = g_ptr_array_index (images, i);
 		FuDfuTargetTransferFlags flags_local = DFU_TARGET_TRANSFER_FLAG_NONE;
