@@ -262,7 +262,7 @@ fu_ebitdo_device_validate (FuEbitdoDevice *self, GError **error)
 		     G_IO_ERROR,
 		     G_IO_ERROR_INVALID_DATA,
 		     "vendor '%s' did not match allowlist, "
-		     "probably not a 8Bitdo device…", ven);
+		     "probably not a 8BitDo device…", ven);
 	return FALSE;
 }
 
@@ -276,7 +276,7 @@ fu_ebitdo_device_open (FuDevice *device, GError **error)
 	if (!FU_DEVICE_CLASS (fu_ebitdo_device_parent_class)->open (device, error))
 		return FALSE;
 
-	/* open, then ensure this is actually 8Bitdo hardware */
+	/* open, then ensure this is actually 8BitDo hardware */
 	if (!fu_ebitdo_device_validate (self, error))
 		return FALSE;
 	if (!g_usb_device_claim_interface (usb_device, 0, /* 0 = idx? */
@@ -389,6 +389,7 @@ fu_ebitdo_device_write_firmware (FuDevice *device,
 		case 0xab12: /* NES30 */
 		case 0xab21: /* SFC30 */
 		case 0xab20: /* SNES30 */
+		case 0x9012: /* SN30v2 */
 			g_string_append (msg, "hold down L+R+START for 3 seconds until "
 					      "both LED lights flashing, ");
 			break;
@@ -409,6 +410,15 @@ fu_ebitdo_device_write_firmware (FuDevice *device,
 			g_string_append (msg, "press and hold L1+R1+START for 3 seconds "
 					      "until the LED on top blinks red, ");
 			break;
+		case 0x2100: /* SN30 for Android */
+		case 0x2101: /* SN30 for Android */
+			g_string_append (msg, "press and hold LB+RB+Xbox buttons "
+					      "both white LED and green LED blink, ");
+			break;
+		case 0x9015: /* N30 Pro 2 */
+ 		    g_string_append (msg, "press and hold L1+R1+START buttons "
+ 					      "until the yellow LED blinks, ");
+			break;
 		default:
 			g_string_append (msg, "do what it says in the manual, ");
 			break;
@@ -565,7 +575,7 @@ fu_ebitdo_device_probe (FuDevice *device, GError **error)
 
 	/* set name and vendor */
 	fu_device_set_summary (device, "A redesigned classic game controller");
-	fu_device_set_vendor (device, "8Bitdo");
+	fu_device_set_vendor (device, "8BitDo");
 
 	/* add a hardcoded icon name */
 	fu_device_add_icon (device, "input-gaming");
@@ -596,8 +606,9 @@ fu_ebitdo_device_prepare_firmware (FuDevice *device,
 static void
 fu_ebitdo_device_init (FuEbitdoDevice *self)
 {
-	fu_device_set_protocol (FU_DEVICE (self), "com.8bitdo");
+	fu_device_add_protocol (FU_DEVICE (self), "com.8bitdo");
 	fu_device_add_flag (FU_DEVICE (self), FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS);
+	fu_device_add_internal_flag (FU_DEVICE (self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
 }
 
 static void
