@@ -9,7 +9,6 @@
 #include "fu-ebitdo-device.h"
 
 #include "fu-plugin-vfuncs.h"
-#include "fu-hash.h"
 #include "fu-ebitdo-firmware.h"
 
 void
@@ -17,5 +16,5 @@ fu_plugin_init (FuPlugin *plugin)
 {
 	fu_plugin_set_build_hash (plugin, FU_BUILD_HASH);
 	fu_plugin_set_device_gtype (plugin, FU_TYPE_EBITDO_DEVICE);
-	fu_plugin_add_firmware_gtype (plugin, "8bitdo", FU_TYPE_EBITDO_FIRMWARE);
+	fu_plugin_add_firmware_gtype (plugin, NULL, FU_TYPE_EBITDO_FIRMWARE);
 }
