@@ -33,6 +33,9 @@ fu_plugin_init (FuPlugin *plugin)
 	fu_plugin_add_udev_subsystem (plugin, "i2c-dev");
 	fu_plugin_add_udev_subsystem (plugin, "hidraw");
 	fu_plugin_add_firmware_gtype (plugin, NULL, FU_TYPE_ELANTP_FIRMWARE);
+	fu_plugin_add_possible_quirk_key (plugin, "ElantpI2cTargetAddress");
+	fu_plugin_add_possible_quirk_key (plugin, "ElantpIapPassword");
+	fu_plugin_add_possible_quirk_key (plugin, "ElantpIcPageCount");
 	fu_plugin_set_device_gtype (plugin, FU_TYPE_ELANTP_I2C_DEVICE);
 	fu_plugin_set_device_gtype (plugin, FU_TYPE_ELANTP_HID_DEVICE);
 }
