@@ -148,8 +148,9 @@ fu_jabra_device_init (FuJabraDevice *self)
 {
 	fu_device_add_flag (FU_DEVICE (self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag (FU_DEVICE (self), FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS);
+	fu_device_add_internal_flag (FU_DEVICE (self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
 	fu_device_set_remove_delay (FU_DEVICE (self), 20000); /* 10+10s! */
-	fu_device_set_protocol (FU_DEVICE (self), "org.usb.dfu");
+	fu_device_add_protocol (FU_DEVICE (self), "org.usb.dfu");
 }
 
 static void
