@@ -24,6 +24,7 @@ fu_plugin_init (FuPlugin *plugin)
 	FuPluginData *priv = fu_plugin_alloc_data (plugin, sizeof (FuPluginData));
 	fu_plugin_set_build_hash (plugin, FU_BUILD_HASH);
 	fu_plugin_add_udev_subsystem (plugin, "pci");
+	fu_plugin_add_possible_quirk_key (plugin, "PciBcrAddr");
 
 	/* this is true except for some Atoms */
 	priv->bcr_addr = 0xdc;
@@ -43,8 +44,9 @@ void
 fu_plugin_device_registered (FuPlugin *plugin, FuDevice *dev)
 {
 	FuPluginData *priv = fu_plugin_get_data (plugin);
-	if (g_strcmp0 (fu_device_get_plugin (dev), "cpu") == 0) {
-		guint tmp = fu_device_get_metadata_integer (dev, "BcrAddr");
+	if (g_strcmp0 (fu_device_get_plugin (dev), "cpu") == 0 ||
+	    g_strcmp0 (fu_device_get_plugin (dev), "flashrom") == 0) {
+		guint tmp = fu_device_get_metadata_integer (dev, "PciBcrAddr");
 		if (tmp != G_MAXUINT && priv->bcr_addr != tmp) {
 			g_debug ("overriding BCR addr from 0x%02x to 0x%02x",
 				 priv->bcr_addr, tmp);
