@@ -19,8 +19,12 @@
 #include "fu-pxi-firmware.h"
 
 #define PXI_HID_DEV_OTA_INPUT_REPORT_ID		0x05
+#define PXI_HID_DEV_OTA_RETRANSMIT_REPORT_ID	0x06
 #define PXI_HID_DEV_OTA_FEATURE_REPORT_ID	0x07
 
+#define PXI_HID_DEV_OTA_REPORT_USAGE_PAGE	0xff02u
+#define PXI_HID_DEV_OTA_RETRANSMIT_USAGE_PAGE	0xff01u
+
 #define FU_PXI_DEVICE_CMD_FW_OTA_INIT		0x10u
 #define FU_PXI_DEVICE_CMD_FW_WRITE		0x17u
 #define FU_PXI_DEVICE_CMD_FW_UPGRADE		0x18u
@@ -30,12 +34,16 @@
 #define FU_PXI_DEVICE_CMD_FW_OTA_INIT_NEW	0x27u
 #define FU_PXI_DEVICE_CMD_FW_OTA_RETRANSMIT	0x28u
 #define FU_PXI_DEVICE_CMD_FW_OTA_DISCONNECT	0x29u
+#define FU_PXI_DEVICE_CMD_FW_OTA_GET_MODEL	0x2bu
+#define ERR_COMMAND_SUCCESS			0x0
 
 #define FU_PXI_DEVICE_OBJECT_SIZE_MAX		4096	/* bytes */
 #define FU_PXI_DEVICE_OTA_BUF_SZ		512	/* bytes */
 #define FU_PXI_DEVICE_NOTTFY_RET_LEN		4	/* bytes */
 #define FU_PXI_DEVICE_FW_INFO_RET_LEN		8	/* bytes */
 
+#define FU_PXI_DEVICE_NOTIFY_TIMEOUT_MS		5000
+
 /* OTA target selection */
 enum ota_process_setting {
 	OTA_MAIN_FW,				/* Main firmware */
@@ -50,6 +58,7 @@ enum ota_spec_check_result {
 	OTA_PROCESS_ILLEGAL		= 3,	/* Illegal OTA process */
 	OTA_RECONNECT			= 4,	/* Inform OTA app do reconnect */
 	OTA_FW_IMG_VERSION_ERROR	= 5,	/* FW image file version check error */
+	OTA_DEVICE_LOW_BATTERY		= 6,	/* Device is under low battery */
 	OTA_SPEC_CHECK_MAX_NUM,			/* Max number of OTA driver defined error code */
 };
 
@@ -62,6 +71,7 @@ enum ota_disconnect_reason {
 
 struct _FuPxiDevice {
 	FuUdevDevice	 parent_instance;
+	guint8		 retransmit_id;
 	guint8		 status;
 	guint8		 new_flow;
 	guint16		 offset;
@@ -70,6 +80,7 @@ struct _FuPxiDevice {
 	guint16		 mtu_size;
 	guint16		 prn_threshold;
 	guint8		 spec_check_result;
+	gchar		*model_name;
 };
 
 G_DEFINE_TYPE (FuPxiDevice, fu_pxi_device, FU_TYPE_UDEV_DEVICE)
@@ -100,6 +111,8 @@ fu_pxi_device_spec_check_result_to_string (guint8 spec_check_result)
 		return "reconnect";
 	if (spec_check_result == OTA_FW_IMG_VERSION_ERROR)
 		return "fw-img-version-error";
+	if (spec_check_result == OTA_DEVICE_LOW_BATTERY)
+		return "device battery is too low";
 	return NULL;
 }
 
@@ -107,6 +120,11 @@ static void
 fu_pxi_device_to_string (FuDevice *device, guint idt, GString *str)
 {
 	FuPxiDevice *self = FU_PXI_DEVICE (device);
+
+	/* FuUdevDevice->to_string */
+	FU_DEVICE_CLASS (fu_pxi_device_parent_class)->to_string (device, idt, str);
+
+	fu_common_string_append_kv (str, idt, "ModelName", self->model_name);
 	fu_common_string_append_kx (str, idt, "Status", self->status);
 	fu_common_string_append_kx (str, idt, "NewFlow", self->new_flow);
 	fu_common_string_append_kx (str, idt, "CurrentObjectOffset", self->offset);
@@ -116,6 +134,7 @@ fu_pxi_device_to_string (FuDevice *device, guint idt, GString *str)
 	fu_common_string_append_kx (str, idt, "PacketReceiptNotificationThreshold", self->prn_threshold);
 	fu_common_string_append_kv (str, idt, "SpecCheckResult",
 				    fu_pxi_device_spec_check_result_to_string (self->spec_check_result));
+	fu_common_string_append_kx (str, idt, "RetransmitID", self->retransmit_id);
 }
 
 static FuFirmware *
@@ -124,9 +143,34 @@ fu_pxi_device_prepare_firmware (FuDevice *device,
 				FwupdInstallFlags flags,
 				GError **error)
 {
+	FuPxiDevice *self = FU_PXI_DEVICE (device);
+	const gchar *model_name;
 	g_autoptr(FuFirmware) firmware = fu_pxi_firmware_new ();
+
 	if (!fu_firmware_parse (firmware, fw, flags, error))
 		return NULL;
+
+	/* check is compatible with hardware */
+	model_name = fu_pxi_firmware_get_model_name (FU_PXI_FIRMWARE (firmware));
+	if ((flags & FWUPD_INSTALL_FLAG_FORCE) == 0) {
+		if (self->model_name == NULL || model_name == NULL) {
+			g_set_error_literal (error,
+					     FWUPD_ERROR,
+					     FWUPD_ERROR_INVALID_FILE,
+					     "legacy device or firmware detected, "
+					     "--force required");
+			return NULL;
+		}
+		if (g_strcmp0 (self->model_name, model_name) != 0) {
+			g_set_error (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_INVALID_FILE,
+				     "incompatible firmware, got %s, expected %s.",
+				     model_name, self->model_name);
+			return NULL;
+		}
+	}
+
 	return g_steal_pointer (&firmware);
 }
 
@@ -161,6 +205,16 @@ fu_pxi_device_get_feature (FuPxiDevice *self, guint8 *buf, guint bufsz, GError *
 	}
 	if (g_getenv ("FWUPD_PIXART_RF_VERBOSE") != NULL)
 		fu_common_dump_raw (G_LOG_DOMAIN, "GetFeature", buf, bufsz);
+
+	/* prepend the report-id and cmd for versions of bluez that do not have
+	 * https://github.com/bluez/bluez/commit/35a2c50437cca4d26ac6537ce3a964bb509c9b62 */
+	if (bufsz > 2 && buf[0] != PXI_HID_DEV_OTA_FEATURE_REPORT_ID) {
+		g_debug ("doing fixup for old bluez version");
+		memmove (buf + 2, buf, bufsz - 2);
+		buf[0] = PXI_HID_DEV_OTA_FEATURE_REPORT_ID;
+		buf[1] = 0x0;
+	}
+
 	return TRUE;
 #else
 	g_set_error_literal (error,
@@ -180,6 +234,99 @@ fu_pxi_device_calculate_checksum (const guint8 *buf, gsize bufsz)
 	return checksum;
 }
 
+static gboolean
+fu_pxi_device_search_hid_usage_page (guint8 *report_descriptor, gint size,
+				     guint8 *usage_page, guint8 usage_page_sz)
+{
+	gint pos = 0;
+
+	if (g_getenv ("FWUPD_PIXART_RF_VERBOSE") != NULL) {
+		fu_common_dump_raw (G_LOG_DOMAIN, "target usage_page",
+				    usage_page, usage_page_sz);
+	}
+
+	while (pos < size) {
+		/* HID info define by HID specification */
+		guint8 item = report_descriptor[pos];
+		guint8 report_size = item & 0x03;
+		guint8 report_tag =  item & 0xF0;
+		guint8 usage_page_tmp[4] = {0x00};
+
+		report_size = (report_size == 3) ? 4 : report_size;
+
+		if (report_tag != 0) {
+			pos += report_size + 1;
+			continue;
+		}
+
+		memmove (usage_page, &report_descriptor[pos + 1], report_size);
+		if (memcmp (usage_page, usage_page_tmp, usage_page_sz) == 0) {
+			if (g_getenv ("FWUPD_PIXART_RF_VERBOSE") != NULL) {
+				g_debug ("hit item: %x  ",item);
+				fu_common_dump_raw (G_LOG_DOMAIN, "usage_page", usage_page, report_size);
+				g_debug ("hit pos %d",pos);
+			}
+			return TRUE; 	/* finished processing */
+		}
+		pos += report_size + 1;
+	}
+
+	return FALSE ; /* finished processing */
+}
+
+static gboolean
+fu_pxi_device_check_support_report_id (FuPxiDevice *self,
+				       GError **error)
+{
+#ifdef HAVE_HIDRAW_H
+	gint desc_size = 0;
+	g_autoptr(GByteArray) req = g_byte_array_new ();
+
+	struct hidraw_report_descriptor rpt_desc;
+
+	/* Get Report Descriptor Size */
+	if (!fu_udev_device_ioctl (FU_UDEV_DEVICE (self), HIDIOCGRDESCSIZE,
+				   (guint8*)&desc_size, NULL, error))
+		return FALSE;
+
+	rpt_desc.size = desc_size;
+	if (!fu_udev_device_ioctl (FU_UDEV_DEVICE (self), HIDIOCGRDESC,
+			           (guint8*)&rpt_desc,
+				   NULL, error))
+		return FALSE;
+	fu_common_dump_raw (G_LOG_DOMAIN, "HID descriptor",
+			    rpt_desc.value, rpt_desc.size);
+
+
+	/* check ota retransmit feature report usage page exist or not */
+	fu_byte_array_append_uint16 (req, PXI_HID_DEV_OTA_RETRANSMIT_USAGE_PAGE, G_LITTLE_ENDIAN);
+	if (!fu_pxi_device_search_hid_usage_page (rpt_desc.value, rpt_desc.size,
+						  req->data, req->len)) {
+		/* replace retransmit report id with feature report id, if retransmit report id not found */
+		self->retransmit_id = PXI_HID_DEV_OTA_FEATURE_REPORT_ID;
+	}
+	return TRUE;
+
+#else
+	g_set_error_literal (error,
+			     G_IO_ERROR,
+			     G_IO_ERROR_NOT_SUPPORTED,
+			     "<linux/hidraw.h> not available");
+	return FALSE
+#endif
+}
+
+static gboolean
+fu_pxi_device_fw_ota_check_retransmit (FuPxiDevice *self, GError **error)
+{
+	g_autoptr(GByteArray) req = g_byte_array_new ();
+
+	/* write fw ota retransmit command to reset the ota state */
+	fu_byte_array_append_uint8 (req, self->retransmit_id);
+	fu_byte_array_append_uint8 (req, FU_PXI_DEVICE_CMD_FW_OTA_RETRANSMIT);
+	return fu_pxi_device_set_feature (self, req, error);
+}
+
 static gboolean
 fu_pxi_device_check_support_resume (FuPxiDevice *self,
 				    FuFirmware *firmware,
@@ -237,18 +384,51 @@ fu_pxi_device_wait_notify (FuPxiDevice *self,
 			   guint16 *checksum,
 			   GError **error)
 {
-	guint8 res[FU_PXI_DEVICE_OTA_BUF_SZ] = {
-		PXI_HID_DEV_OTA_INPUT_REPORT_ID,
-		0x0,
-	};
-	if (!fu_udev_device_pread_full (FU_UDEV_DEVICE (self),
-					port, res, (FU_PXI_DEVICE_NOTTFY_RET_LEN + 1) - port,
-					error))
-		return FALSE;
-	if (status != NULL) {
-		if (!fu_common_read_uint8_safe (res, sizeof(res), 0x1,
-						status, error))
+	g_autoptr(GTimer) timer = g_timer_new ();
+	guint8 res[FU_PXI_DEVICE_OTA_BUF_SZ] = { 0 };
+	guint8 cmd_status = 0x0;
+
+	/* skip the wrong report id ,and keep polling until result is correct */
+	while (g_timer_elapsed (timer, NULL) * 1000.f < FU_PXI_DEVICE_NOTIFY_TIMEOUT_MS) {
+		if (!fu_udev_device_pread_full (FU_UDEV_DEVICE (self),
+						port, res, (FU_PXI_DEVICE_NOTTFY_RET_LEN + 1) - port,
+						error))
 			return FALSE;
+		if (res[0] == PXI_HID_DEV_OTA_INPUT_REPORT_ID)
+			break;
+	}
+
+	/* timeout */
+	if (res[0] != PXI_HID_DEV_OTA_INPUT_REPORT_ID) {
+		g_set_error_literal (error,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_INTERNAL,
+				     "Timed-out waiting for HID report");
+		return FALSE;
+	}
+	/* get the opcode if status is not null */
+	if (status != NULL) {
+		guint8 status_tmp = 0x0;
+		if (!fu_common_read_uint8_safe (res, sizeof(res), 0x1,
+						&status_tmp, error))
+			return FALSE;
+		/* need check command result if command is fw upgrade */
+		if (status_tmp == FU_PXI_DEVICE_CMD_FW_UPGRADE) {
+			if (!fu_common_read_uint8_safe (res, sizeof(res), 0x2,
+							&cmd_status, error))
+				return FALSE;
+			if (cmd_status != ERR_COMMAND_SUCCESS) {
+				g_set_error (error,
+					     FWUPD_ERROR,
+					     FWUPD_ERROR_READ,
+					     "cmd status was 0x%02x",
+					     cmd_status);
+				return FALSE;
+			}
+		}
+
+		/* propagate */
+		*status = status_tmp;
 	}
 	if (checksum != NULL) {
 		if (!fu_common_read_uint16_safe (res, sizeof(res), 0x3,
@@ -366,8 +546,8 @@ fu_pxi_device_reset (FuPxiDevice *self, GError **error)
 {
 	g_autoptr(GByteArray) req = g_byte_array_new ();
 	fu_byte_array_append_uint8 (req, PXI_HID_DEV_OTA_FEATURE_REPORT_ID);
-	fu_byte_array_append_uint8 (req, FU_PXI_DEVICE_CMD_FW_MCU_RESET);
-	fu_byte_array_append_uint8 (req, OTA_RESET);
+	fu_byte_array_append_uint8 (req, FU_PXI_DEVICE_CMD_FW_MCU_RESET);	/* OTA reset command */
+	fu_byte_array_append_uint8 (req, OTA_RESET);				/* OTA reset reason  */
 	fu_device_set_status (FU_DEVICE (self), FWUPD_STATUS_DEVICE_RESTART);
 
 	if (!fu_pxi_device_set_feature (self, req, error)) {
@@ -417,28 +597,28 @@ fu_pxi_device_fw_ota_init_new (FuPxiDevice *self, gsize bufsz, GError **error)
 		return FALSE;
 
 	/* shared state */
-	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x3,
+	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x5,
 					&self->status, error))
 		return FALSE;
-	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x4,
+	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x6,
 					&self->new_flow, error))
 		return FALSE;
-	if (!fu_common_read_uint16_safe (res, sizeof(res), 0x5,
+	if (!fu_common_read_uint16_safe (res, sizeof(res), 0x7,
 					 &self->offset, G_LITTLE_ENDIAN, error))
 		return FALSE;
-	if (!fu_common_read_uint16_safe (res, sizeof(res), 0x7,
+	if (!fu_common_read_uint16_safe (res, sizeof(res), 0x9,
 					 &self->checksum, G_LITTLE_ENDIAN, error))
 		return FALSE;
-	if (!fu_common_read_uint32_safe (res, sizeof(res), 0x9,
+	if (!fu_common_read_uint32_safe (res, sizeof(res), 0xb,
 					 &self->max_object_size, G_LITTLE_ENDIAN, error))
 		return FALSE;
-	if (!fu_common_read_uint16_safe (res, sizeof(res), 0xd,
+	if (!fu_common_read_uint16_safe (res, sizeof(res), 0xf,
 					 &self->mtu_size, G_LITTLE_ENDIAN, error))
 		return FALSE;
-	if (!fu_common_read_uint16_safe (res, sizeof(res), 0xf,
+	if (!fu_common_read_uint16_safe (res, sizeof(res), 0x11,
 					 &self->prn_threshold, G_LITTLE_ENDIAN, error))
 		return FALSE;
-	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x11,
+	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x13,
 					&self->spec_check_result, error))
 		return FALSE;
 
@@ -447,7 +627,7 @@ fu_pxi_device_fw_ota_init_new (FuPxiDevice *self, gsize bufsz, GError **error)
 		g_set_error (error,
 			     FWUPD_ERROR,
 			     FWUPD_ERROR_READ,
-			     "FwInitNew spec check fail with %s [0x%02x]",
+			     "FwInitNew spec check fail: %s [0x%02x]",
 			     fu_pxi_device_spec_check_result_to_string (self->spec_check_result),
 			     self->spec_check_result);
 		return FALSE;
@@ -463,7 +643,7 @@ fu_pxi_device_fw_upgrade (FuPxiDevice *self, FuFirmware *firmware, GError **erro
 	const gchar *version;
 	const guint8 *buf;
 	gsize bufsz = 0;
-	guint8 fw_version[10] = { 0x0 };
+	guint8 fw_version[5] = { 0x0 };
 	guint8 opcode = 0;
 	guint16 checksum;
 	g_autoptr(GBytes) fw = NULL;
@@ -493,9 +673,15 @@ fu_pxi_device_fw_upgrade (FuPxiDevice *self, FuFirmware *firmware, GError **erro
 	if (g_getenv ("FWUPD_PIXART_RF_VERBOSE") != NULL)
 		fu_common_dump_raw (G_LOG_DOMAIN, "fw upgrade", req->data, req->len);
 
-	/* read fw upgrade command result */
-	if (!fu_pxi_device_wait_notify (self, 0x1, &opcode, NULL, error))
+	/* wait fw upgrade command result */
+	if (!fu_pxi_device_wait_notify (self, 0x1, &opcode, NULL, error)) {
+		g_prefix_error (error,
+				"FwUpgrade command fail, "
+				"fw-checksum: 0x%04x fw-size: %" G_GSIZE_FORMAT ": ",
+				checksum,
+				bufsz);
 		return FALSE;
+	}
 	if (opcode != FU_PXI_DEVICE_CMD_FW_UPGRADE) {
 		g_set_error (error,
 			     FWUPD_ERROR,
@@ -525,8 +711,14 @@ fu_pxi_device_write_firmware (FuDevice *device,
 	if (fw == NULL)
 		return FALSE;
 
-	/* send fw ota init command */
+
+	/* send fw ota retransmit command to reset status */
 	fu_device_set_status (device, FWUPD_STATUS_DEVICE_BUSY);
+	if (!fu_pxi_device_fw_ota_check_retransmit (self, error)) {
+		g_prefix_error (error, "failed to OTA check retransmit: ");
+		return FALSE;
+	}
+	/* send fw ota init command */
 	if (!fu_pxi_device_fw_ota_init (self, error))
 		return FALSE;
 	if (!fu_pxi_device_fw_ota_init_new (self, g_bytes_get_size (fw), error))
@@ -571,11 +763,16 @@ fu_pxi_device_fw_get_info (FuPxiDevice *self, GError **error)
 	if (!fu_pxi_device_set_feature (self, req, error))
 		return FALSE;
 
+
+	/* delay for BLE device read command */
+	g_usleep (10 * 1000);
+
 	res[0] = PXI_HID_DEV_OTA_FEATURE_REPORT_ID;
 	res[1] = FU_PXI_DEVICE_CMD_FW_GET_INFO;
-	if (!fu_pxi_device_get_feature (self, res, FU_PXI_DEVICE_FW_INFO_RET_LEN + 1, error))
+
+	if (!fu_pxi_device_get_feature (self, res, FU_PXI_DEVICE_FW_INFO_RET_LEN + 3, error))
 		return FALSE;
-	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x2, &opcode, error))
+	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x4, &opcode, error))
 		return FALSE;
 	if (opcode != FU_PXI_DEVICE_CMD_FW_GET_INFO) {
 		g_set_error (error,
@@ -586,11 +783,11 @@ fu_pxi_device_fw_get_info (FuPxiDevice *self, GError **error)
 		return FALSE;
 	}
 	/* set current version */
-	version_str = g_strndup ((gchar *) res + 0x4, 5);
+	version_str = g_strndup ((gchar *) res + 0x6, 5);
 	fu_device_set_version (FU_DEVICE (self), version_str);
 
 	/* add current checksum */
-	if (!fu_common_read_uint16_safe (res, sizeof(res), 0x9,
+	if (!fu_common_read_uint16_safe (res, sizeof(res), 0xb,
 					 &checksum, G_LITTLE_ENDIAN, error))
 		return FALSE;
 
@@ -598,10 +795,52 @@ fu_pxi_device_fw_get_info (FuPxiDevice *self, GError **error)
 	return TRUE;
 }
 
+static gboolean
+fu_pxi_device_get_model_info (FuPxiDevice *self, GError **error)
+{
+	guint8 res[FU_PXI_DEVICE_OTA_BUF_SZ] = { 0x0 };
+	guint8 opcode = 0x0;
+	guint8 model_name[FU_PXI_DEVICE_MODEL_NAME_LEN] = { 0x0 };
+	g_autoptr(GByteArray) req = g_byte_array_new ();
+
+	fu_byte_array_append_uint8 (req, PXI_HID_DEV_OTA_FEATURE_REPORT_ID);
+	fu_byte_array_append_uint8 (req, FU_PXI_DEVICE_CMD_FW_OTA_GET_MODEL);
+
+	if (!fu_pxi_device_set_feature (self, req, error))
+		return FALSE;
+
+	/* delay for BLE device read command */
+	g_usleep (10 * 1000);
+
+	res[0] = PXI_HID_DEV_OTA_FEATURE_REPORT_ID;
+	if (!fu_pxi_device_get_feature (self, res, sizeof(res), error))
+		return FALSE;
+	if (!fu_common_read_uint8_safe (res, sizeof(res), 0x4, &opcode, error))
+		return FALSE;
+
+	/* old firmware */
+	if (opcode != FU_PXI_DEVICE_CMD_FW_OTA_GET_MODEL)
+		return TRUE;
+
+	/* get model from res */
+	if (!fu_memcpy_safe (model_name, sizeof(model_name), 0x0,	/* dst */
+			     (guint8 *) res, sizeof(res), 0x6,		/* src */
+			     sizeof(model_name), error))
+		return FALSE;
+	g_clear_pointer (&self->model_name, g_free);
+	if (model_name[0] != 0x00 && model_name[0] != 0xFF)
+		self->model_name = g_strndup ((gchar *) model_name, sizeof(model_name));
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_pxi_device_probe (FuDevice *device, GError **error)
 {
-	/* set the physical ID */
+	/* set the logical and physical ID */
+	if (!fu_udev_device_set_logical_id (FU_UDEV_DEVICE (device), "hid", error))
+		return FALSE;
 	return fu_udev_device_set_physical_id (FU_UDEV_DEVICE (device), "hid", error);
 }
 
@@ -613,7 +852,7 @@ fu_pxi_device_setup_guid (FuPxiDevice *self, GError **error)
 	g_autofree gchar *devid = NULL;
 	g_autoptr(GString) dev_name = NULL;
 
-	/* extra GUID */
+	/* extra GUID with device name */
 	if (!fu_pxi_device_get_raw_info (self, &hid_raw_info ,error))
 		return FALSE;
 	dev_name = g_string_new (fu_device_get_name (FU_DEVICE (self)));
@@ -624,6 +863,20 @@ fu_pxi_device_setup_guid (FuPxiDevice *self, GError **error)
 				 (guint) hid_raw_info.product,
 				 dev_name->str);
 	fu_device_add_instance_id (FU_DEVICE (self), devid);
+
+	/* extra GUID with model name*/
+	if (self->model_name != NULL) {
+		g_autofree gchar *devid2 = NULL;
+		g_autoptr(GString) model_name = NULL;
+		model_name = g_string_new (self->model_name);
+		g_string_ascii_up (model_name);
+		fu_common_string_replace (model_name, " ", "_");
+		devid2 = g_strdup_printf ("HIDRAW\\VEN_%04X&DEV_%04X&MODEL_%s",
+					 (guint) hid_raw_info.vendor,
+					 (guint) hid_raw_info.product,
+					 model_name->str);
+		fu_device_add_instance_id (FU_DEVICE (self), devid2);
+	}
 #endif
 	return TRUE;
 }
@@ -633,8 +886,11 @@ fu_pxi_device_setup (FuDevice *device, GError **error)
 {
 	FuPxiDevice *self = FU_PXI_DEVICE (device);
 
-	if (!fu_pxi_device_setup_guid (self ,error)) {
-		g_prefix_error (error, "failed to setup GUID: ");
+	if (!fu_pxi_device_check_support_report_id (self, error)) {
+		g_prefix_error (error, "failed to check report id: ");
+	}
+	if (!fu_pxi_device_fw_ota_check_retransmit (self, error)) {
+		g_prefix_error (error, "failed to OTA check retransmit: ");
 		return FALSE;
 	}
 	if (!fu_pxi_device_fw_ota_init (self, error)) {
@@ -645,6 +901,15 @@ fu_pxi_device_setup (FuDevice *device, GError **error)
 		g_prefix_error (error, "failed to get info: ");
 		return FALSE;
 	}
+	if (!fu_pxi_device_get_model_info (self ,error)) {
+		g_prefix_error (error, "failed to get model: ");
+		return FALSE;
+	}
+	if (!fu_pxi_device_setup_guid (self ,error)) {
+		g_prefix_error (error, "failed to setup GUID: ");
+		return FALSE;
+	}
+
 	return TRUE;
 }
 
@@ -654,13 +919,23 @@ fu_pxi_device_init (FuPxiDevice *self)
 	fu_device_add_flag (FU_DEVICE (self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_set_version_format (FU_DEVICE (self), FWUPD_VERSION_FORMAT_TRIPLET);
 	fu_device_add_vendor_id (FU_DEVICE (self), "USB:0x093A");
-	fu_device_set_protocol (FU_DEVICE (self), "com.pixart.rf");
+	fu_device_add_protocol (FU_DEVICE (self), "com.pixart.rf");
+	self->retransmit_id = PXI_HID_DEV_OTA_RETRANSMIT_REPORT_ID;
+}
+
+static void
+fu_pxi_device_finalize (GObject *object)
+{
+	FuPxiDevice *self = FU_PXI_DEVICE (object);
+	g_free (self->model_name);
 }
 
 static void
 fu_pxi_device_class_init (FuPxiDeviceClass *klass)
 {
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	FuDeviceClass *klass_device = FU_DEVICE_CLASS (klass);
+	object_class->finalize = fu_pxi_device_finalize;
 	klass_device->probe = fu_pxi_device_probe;
 	klass_device->setup = fu_pxi_device_setup;
 	klass_device->to_string = fu_pxi_device_to_string;
