@@ -64,7 +64,7 @@ fu_redfish_client_fetch_data (FuRedfishClient *self, const gchar *uri_path, GErr
 	/* create URI */
 #ifdef HAVE_LIBCURL_7_62_0
 	uri = curl_url ();
-	curl_url_set (uri, CURLU_DEFAULT_SCHEME, self->use_https ? "https" : "http", 0);
+	curl_url_set (uri, CURLUPART_SCHEME, self->use_https ? "https" : "http", 0);
 	curl_url_set (uri, CURLUPART_PATH, uri_path, 0);
 	curl_url_set (uri, CURLUPART_HOST, self->hostname, 0);
 	curl_url_set (uri, CURLUPART_PORT, port, 0);
@@ -125,6 +125,7 @@ fu_redfish_client_coldplug_member (FuRedfishClient *self,
 {
 	g_autoptr(FuDevice) dev = NULL;
 	const gchar *guid = NULL;
+	g_autofree gchar *guid_lower = NULL;
 	g_autofree gchar *id = NULL;
 
 	if (json_object_has_member (member, "SoftwareId")) {
@@ -147,9 +148,10 @@ fu_redfish_client_coldplug_member (FuRedfishClient *self,
 	id = g_strdup_printf ("Redfish-Inventory-%s",
 			      json_object_get_string_member (member, "Id"));
 	fu_device_set_id (dev, id);
-	fu_device_set_protocol (dev, "org.dmtf.redfish");
+	fu_device_add_protocol (dev, "org.dmtf.redfish");
 
-	fu_device_add_guid (dev, guid);
+	guid_lower = g_ascii_strdown (guid, -1);
+	fu_device_add_guid (dev, guid_lower);
 	if (json_object_has_member (member, "Name"))
 		fu_device_set_name (dev, json_object_get_string_member (member, "Name"));
 	fu_device_set_summary (dev, "Redfish device");
@@ -623,7 +625,7 @@ fu_redfish_client_update (FuRedfishClient *self, FuDevice *device, GBytes *blob_
 
 	/* create URI */
 #ifdef HAVE_LIBCURL_7_62_0
-	curl_url_set (uri, CURLU_DEFAULT_SCHEME, self->use_https ? "https" : "http", 0);
+	curl_url_set (uri, CURLUPART_SCHEME, self->use_https ? "https" : "http", 0);
 	curl_url_set (uri, CURLUPART_PATH, self->push_uri_path, 0);
 	curl_url_set (uri, CURLUPART_HOST, self->hostname, 0);
 	curl_url_set (uri, CURLUPART_PORT, port, 0);
