@@ -19,53 +19,32 @@ fu_plugin_superio_coldplug_chipset (FuPlugin *plugin, const gchar *chipset, GErr
 	const gchar *dmi_vendor;
 	g_autoptr(FuSuperioDevice) dev = NULL;
 	g_autoptr(FuDeviceLocker) locker = NULL;
-	g_autofree gchar *key = g_strdup_printf ("SuperIO=%s", chipset);
-	guint64 id;
-	guint64 port;
-
-	/* get ID we need for the chipset */
-	id = fu_plugin_lookup_quirk_by_id_as_uint64 (plugin, key, "Id");
-	if (id == 0x0000 || id > 0xffff) {
-		g_set_error (error,
-			     G_IO_ERROR,
-			     G_IO_ERROR_NOT_SUPPORTED,
-			     "SuperIO chip %s has invalid Id", chipset);
-		return FALSE;
-	}
-
-	/* set address */
-	port = fu_plugin_lookup_quirk_by_id_as_uint64 (plugin, key, "Port");
-	if (port == 0x0 || port > 0xffff) {
-		g_set_error (error,
-			     G_IO_ERROR,
-			     G_IO_ERROR_NOT_SUPPORTED,
-			     "SuperIO chip %s has invalid Port", chipset);
-		return FALSE;
-	}
 
 	/* create IT89xx or IT89xx */
-	if (id >> 8 == 0x85) {
+	if (g_strcmp0 (chipset, "IT8587") == 0) {
 		dev = g_object_new (FU_TYPE_SUPERIO_IT85_DEVICE,
 				    "device-file", "/dev/port",
 				    "chipset", chipset,
-				    "id", id,
-				    "port", port,
+				    "quirks", fu_plugin_get_quirks (plugin),
 				    NULL);
-	} else if (id >> 8 == 0x89) {
+	} else if (g_strcmp0 (chipset, "IT8987") == 0) {
 		dev = g_object_new (FU_TYPE_SUPERIO_IT89_DEVICE,
 				    "device-file", "/dev/port",
 				    "chipset", chipset,
-				    "id", id,
-				    "port", port,
+				    "quirks", fu_plugin_get_quirks (plugin),
 				    NULL);
 	} else {
 		g_set_error (error,
 			     G_IO_ERROR,
 			     G_IO_ERROR_NOT_SUPPORTED,
-			     "SuperIO chip %s has unsupported Id", chipset);
+			     "SuperIO chip %s has unsupported SuperioId", chipset);
 		return FALSE;
 	}
 
+	/* set ID and port via quirks */
+	if (!fu_device_probe (FU_DEVICE (dev), error))
+		return FALSE;
+
 	/* set vendor ID as the motherboard vendor */
 	dmi_vendor = fu_plugin_get_dmi_value (plugin, FU_HWIDS_KEY_BASEBOARD_MANUFACTURER);
 	if (dmi_vendor != NULL) {
@@ -82,22 +61,14 @@ fu_plugin_superio_coldplug_chipset (FuPlugin *plugin, const gchar *chipset, GErr
 	return TRUE;
 }
 
-static gboolean
-fu_plugin_superio_coldplug_chipsets (FuPlugin *plugin, const gchar *str, GError **error)
-{
-	g_auto(GStrv) chipsets = g_strsplit (str, ",", -1);
-	for (guint i = 0; chipsets[i] != NULL; i++) {
-		if (!fu_plugin_superio_coldplug_chipset (plugin, chipsets[i], error))
-			return FALSE;
-	}
-	return TRUE;
-}
-
 void
 fu_plugin_init (FuPlugin *plugin)
 {
 	fu_plugin_set_build_hash (plugin, FU_BUILD_HASH);
 	fu_plugin_add_rule (plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "linux_lockdown");
+	fu_plugin_add_possible_quirk_key (plugin, "SuperioChipsets");
+	fu_plugin_add_possible_quirk_key (plugin, "SuperioId");
+	fu_plugin_add_possible_quirk_key (plugin, "SuperioPort");
 }
 
 gboolean
@@ -117,11 +88,11 @@ fu_plugin_coldplug (FuPlugin *plugin, GError **error)
 	for (guint i = 0; i < hwids->len; i++) {
 		const gchar *tmp;
 		const gchar *guid = g_ptr_array_index (hwids, i);
-		g_autofree gchar *key = g_strdup_printf ("HwId=%s", guid);
+		g_autofree gchar *key = g_strdup_printf ("%s", guid);
 		tmp = fu_plugin_lookup_quirk_by_id (plugin, key, FU_QUIRKS_SUPERIO_CHIPSETS);
 		if (tmp == NULL)
 			continue;
-		if (!fu_plugin_superio_coldplug_chipsets (plugin, tmp, error))
+		if (!fu_plugin_superio_coldplug_chipset (plugin, tmp, error))
 			return FALSE;
 	}
 	return TRUE;
