@@ -147,6 +147,7 @@ static gboolean
 fu_synaptics_rmi_ps2_device_write_byte (FuSynapticsRmiPs2Device *self,
 					guint8 buf,
 					guint timeout,
+					FuSynapticsRmiDeviceFlags flags,
 					GError **error)
 {
 	gboolean do_write = TRUE;
@@ -195,6 +196,11 @@ fu_synaptics_rmi_ps2_device_write_byte (FuSynapticsRmiPs2Device *self,
 			g_usleep (1000 * 10);
 		}
 		if (i >= 3) {
+			if (flags & FU_SYNAPTICS_RMI_DEVICE_FLAG_ALLOW_FAILURE) {
+				/* just break without error return because FW
+				 * will not return ACK for commands like RESET */
+				break;
+			}
 			g_set_error_literal (error,
 					     FWUPD_ERROR,
 					     FWUPD_ERROR_NOT_SUPPORTED,
@@ -215,15 +221,21 @@ fu_synaptics_rmi_ps2_device_set_resolution_sequence (FuSynapticsRmiPs2Device *se
 {
 	/* send set scaling twice if send_e6s */
 	for (gint i = send_e6s ? 2 : 1; i > 0; --i) {
-		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetScaling1To1, 50, error))
+		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetScaling1To1, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error))
 			return FALSE;
 	}
 	for (gint i = 3; i >= 0; --i) {
 		guint8 ucTwoBitArg = (arg >> (i * 2)) & 0x3;
-		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetResolution, 50, error)) {
+		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetResolution, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error)) {
 			return FALSE;
 		}
-		if (!fu_synaptics_rmi_ps2_device_write_byte (self, ucTwoBitArg, 50, error))
+		if (!fu_synaptics_rmi_ps2_device_write_byte (self, ucTwoBitArg, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error))
 			return FALSE;
 	}
 
@@ -253,6 +265,7 @@ fu_synaptics_rmi_ps2_device_status_request_sequence (FuSynapticsRmiPs2Device *se
 		if (!fu_synaptics_rmi_ps2_device_write_byte (self,
 							     edpAuxStatusRequest,
 							     10,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
 							     &error_local)) {
 			g_debug ("failed write try #%u: %s",
 				 i, error_local->message);
@@ -294,8 +307,12 @@ fu_synaptics_rmi_ps2_device_sample_rate_sequence (FuSynapticsRmiPs2Device *self,
 			send_e6s = TRUE;
 		}
 		if (!fu_synaptics_rmi_ps2_device_set_resolution_sequence (self, arg, send_e6s, &error_local) ||
-		    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetSampleRate, 50, &error_local) ||
-		    !fu_synaptics_rmi_ps2_device_write_byte (self, param, 50, &error_local)) {
+		    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetSampleRate, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     &error_local) ||
+		    !fu_synaptics_rmi_ps2_device_write_byte (self, param, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     &error_local)) {
 			if (i > 3) {
 				g_propagate_error (error, g_steal_pointer (&error_local));
 				return FALSE;
@@ -315,7 +332,9 @@ fu_synaptics_rmi_ps2_device_detect_synaptics_styk (FuSynapticsRmiPs2Device *self
 						   GError **error)
 {
 	guint8 buf;
-	if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxIBMReadSecondaryID, 10, error)) {
+	if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxIBMReadSecondaryID, 10,
+						     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+						     error)) {
 		g_prefix_error (error, "failed to write IBMReadSecondaryID(0xE1): ");
 		return FALSE;
 	}
@@ -354,6 +373,7 @@ fu_synaptics_rmi_ps2_device_query_build_id (FuSynapticsRmiDevice *rmi_device,
 		g_prefix_error (error, "failed to detect Synaptics styk: ");
 		return FALSE;
 	}
+	fu_synaptics_rmi_device_set_iepmode (rmi_device, FALSE);
 	if (esdr == esdrTouchPad || is_synaptics_styk) {
 		/* Get the firmware id from the Extra Capabilities 2 Byte
 		 * The firmware id is located in bits 0 - 23 */
@@ -390,7 +410,9 @@ fu_synaptics_rmi_ps2_device_enter_iep_mode (FuSynapticsRmiDevice *rmi_device,
 	FuSynapticsRmiPs2Device *self = FU_SYNAPTICS_RMI_PS2_DEVICE (rmi_device);
 
 	/* disable stream */
-	if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxDisable, 50, error)) {
+	if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxDisable, 50,
+						     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+						     error)) {
 		g_prefix_error (error, "failed to disable stream mode: ");
 		return FALSE;
 	}
@@ -415,6 +437,7 @@ fu_synaptics_rmi_ps2_device_write_rmi_register (FuSynapticsRmiPs2Device *self,
 						const guint8 *buf,
 						guint8 buflen,
 						guint timeout,
+						FuSynapticsRmiDeviceFlags flags,
 						GError **error)
 {
 	g_return_val_if_fail (timeout > 0, FALSE);
@@ -424,6 +447,7 @@ fu_synaptics_rmi_ps2_device_write_rmi_register (FuSynapticsRmiPs2Device *self,
 	if (!fu_synaptics_rmi_ps2_device_write_byte (self,
 						     edpAuxSetScaling2To1,
 						     timeout,
+						     flags,
 						     error)) {
 		g_prefix_error (error, "failed to edpAuxSetScaling2To1: ");
 		return FALSE;
@@ -431,6 +455,7 @@ fu_synaptics_rmi_ps2_device_write_rmi_register (FuSynapticsRmiPs2Device *self,
 	if (!fu_synaptics_rmi_ps2_device_write_byte (self,
 						     edpAuxSetSampleRate,
 						     timeout,
+						     flags,
 						     error)) {
 		g_prefix_error (error, "failed to edpAuxSetSampleRate: ");
 		return FALSE;
@@ -438,6 +463,7 @@ fu_synaptics_rmi_ps2_device_write_rmi_register (FuSynapticsRmiPs2Device *self,
 	if (!fu_synaptics_rmi_ps2_device_write_byte (self,
 						     addr,
 						     timeout,
+						     flags,
 						     error)) {
 		g_prefix_error (error, "failed to write address: ");
 		return FALSE;
@@ -446,6 +472,7 @@ fu_synaptics_rmi_ps2_device_write_rmi_register (FuSynapticsRmiPs2Device *self,
 		if (!fu_synaptics_rmi_ps2_device_write_byte (self,
 							     edpAuxSetSampleRate,
 							     timeout,
+							     flags,
 							     error)) {
 			g_prefix_error (error, "failed to set byte %u: ", i);
 			return FALSE;
@@ -453,6 +480,7 @@ fu_synaptics_rmi_ps2_device_write_rmi_register (FuSynapticsRmiPs2Device *self,
 		if (!fu_synaptics_rmi_ps2_device_write_byte (self,
 							     buf[i],
 							     timeout,
+							     flags,
 							     error)) {
 			g_prefix_error (error, "failed to write byte %u: ", i);
 			return FALSE;
@@ -476,10 +504,18 @@ fu_synaptics_rmi_ps2_device_read_rmi_register (FuSynapticsRmiPs2Device *self,
 		return FALSE;
 	for (guint retries = 0; ; retries++) {
 		g_autoptr(GError) error_local = NULL;
-		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetScaling2To1, 50, error) ||
-		    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetSampleRate, 50, error) ||
-		    !fu_synaptics_rmi_ps2_device_write_byte (self, addr, 50, error) ||
-		    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxStatusRequest, 50, error)) {
+		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetScaling2To1, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error) ||
+		    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetSampleRate, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error) ||
+		    !fu_synaptics_rmi_ps2_device_write_byte (self, addr, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error) ||
+		    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxStatusRequest, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error)) {
 			g_prefix_error (error, "failed to write command in Read RMI register: ");
 			return FALSE;
 		}
@@ -516,10 +552,18 @@ fu_synaptics_rmi_ps2_device_read_rmi_packet_register (FuSynapticsRmiPs2Device *s
 
 	if (!fu_synaptics_rmi_ps2_device_enter_iep_mode (FU_SYNAPTICS_RMI_DEVICE (self), error))
 		return NULL;
-	if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetScaling2To1, 50, error) ||
-	    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetSampleRate, 50, error) ||
-	    !fu_synaptics_rmi_ps2_device_write_byte (self, addr, 50, error) ||
-	    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxStatusRequest, 50, error)) {
+	if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetScaling2To1, 50,
+						     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+						     error) ||
+	    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxSetSampleRate, 50,
+						     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+						     error) ||
+	    !fu_synaptics_rmi_ps2_device_write_byte (self, addr,
+						     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+						     FALSE, error) ||
+	    !fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxStatusRequest,
+						     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+						     FALSE, error)) {
 		g_prefix_error (error, "failed to write command in Read RMI Packet Register: ");
 		return NULL;
 	}
@@ -571,6 +615,7 @@ fu_synaptics_rmi_ps2_device_set_page (FuSynapticsRmiDevice *rmi_device,
 							     &page,
 							     1,
 							     20,
+							     FALSE,
 							     error)) {
 		g_prefix_error (error, "failed to write page %u: ", page);
 		return FALSE;
@@ -672,6 +717,7 @@ static gboolean
 fu_synaptics_rmi_ps2_device_write (FuSynapticsRmiDevice *rmi_device,
 				   guint16 addr,
 				   GByteArray *req,
+				   FuSynapticsRmiDeviceFlags flags,
 				   GError **error)
 {
 	FuSynapticsRmiPs2Device *self = FU_SYNAPTICS_RMI_PS2_DEVICE (rmi_device);
@@ -686,6 +732,7 @@ fu_synaptics_rmi_ps2_device_write (FuSynapticsRmiDevice *rmi_device,
 							     req->data,
 							     req->len,
 							     1000, /* timeout */
+							     flags,
 							     error)) {
 		g_prefix_error (error,
 				"failed to write register %x: ",
@@ -711,6 +758,7 @@ fu_synaptics_rmi_ps2_device_write_bus_select (FuSynapticsRmiDevice *rmi_device,
 	if (!fu_synaptics_rmi_ps2_device_write (rmi_device,
 						RMI_DEVICE_BUS_SELECT_REGISTER,
 						req,
+						FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
 						error)) {
 		g_prefix_error (error, "failed to write rmi register %u: ", bus);
 		return FALSE;
@@ -760,7 +808,9 @@ fu_synaptics_rmi_ps2_device_open (FuDevice *device, GError **error)
 		}
 
 		/* send reset -- may take 300-500ms */
-		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxReset, 600, error)) {
+		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxReset, 600,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error)) {
 			g_prefix_error (error, "failed to reset: ");
 			return FALSE;
 		}
@@ -779,7 +829,9 @@ fu_synaptics_rmi_ps2_device_open (FuDevice *device, GError **error)
 		}
 
 		/* disable the device so that it stops reporting finger data */
-		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxDisable, 50, error)) {
+		if (!fu_synaptics_rmi_ps2_device_write_byte (self, edpAuxDisable, 50,
+							     FU_SYNAPTICS_RMI_DEVICE_FLAG_NONE,
+							     error)) {
 			g_prefix_error (error, "failed to disable stream mode: ");
 			return FALSE;
 		}
@@ -878,6 +930,9 @@ fu_synaptics_rmi_ps2_device_attach (FuDevice *device, GError **error)
 		return TRUE;
 	}
 
+	/* Set iepmode before reset device forcibly because of FW requirement */
+	fu_synaptics_rmi_device_set_iepmode (rmi_device, FALSE);
+
 	/* delay after writing */
 	fu_device_set_status (device, FWUPD_STATUS_DEVICE_RESTART);
 	fu_device_sleep_with_progress (device, 2);
