@@ -96,9 +96,10 @@ static void
 fu_thelio_io_device_init (FuThelioIoDevice *self)
 {
 	fu_device_add_flag (FU_DEVICE (self), FWUPD_DEVICE_FLAG_UPDATABLE);
+	fu_device_add_internal_flag (FU_DEVICE (self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
 	fu_device_set_remove_delay (FU_DEVICE (self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 	fu_device_set_version_format (FU_DEVICE (self), FWUPD_VERSION_FORMAT_TRIPLET);
-	fu_device_set_protocol (FU_DEVICE (self), "org.usb.dfu");
+	fu_device_add_protocol (FU_DEVICE (self), "org.usb.dfu");
 }
 
 static void
