@@ -19,6 +19,12 @@ fu_plugin_init (FuPlugin *plugin)
 	fu_plugin_set_build_hash (plugin, FU_BUILD_HASH);
 	fu_plugin_add_firmware_gtype (plugin, NULL, FU_TYPE_VLI_USBHUB_FIRMWARE);
 	fu_plugin_add_firmware_gtype (plugin, NULL, FU_TYPE_VLI_PD_FIRMWARE);
+	fu_plugin_add_possible_quirk_key (plugin, "VliDeviceKind");
+	fu_plugin_add_possible_quirk_key (plugin, "VliSpiAutoDetect");
+	fu_plugin_add_possible_quirk_key (plugin, "VliSpiCmdChipErase");
+	fu_plugin_add_possible_quirk_key (plugin, "VliSpiCmdReadId");
+	fu_plugin_add_possible_quirk_key (plugin, "VliSpiCmdReadIdSz");
+	fu_plugin_add_possible_quirk_key (plugin, "VliSpiCmdSectorErase");
 
 	/* register the custom types */
 	g_type_ensure (FU_TYPE_VLI_USBHUB_DEVICE);
