@@ -16,6 +16,9 @@ fu_plugin_init (FuPlugin *plugin)
 {
 	fu_plugin_set_build_hash (plugin, FU_BUILD_HASH);
 	fu_plugin_add_udev_subsystem (plugin, "hidraw");
+	fu_plugin_add_possible_quirk_key (plugin, "WacomI2cFlashBlockSize");
+	fu_plugin_add_possible_quirk_key (plugin, "WacomI2cFlashBaseAddr");
+	fu_plugin_add_possible_quirk_key (plugin, "WacomI2cFlashSize");
 
 	/* register the custom types */
 	g_type_ensure (FU_TYPE_WACOM_AES_DEVICE);
