@@ -122,11 +122,13 @@ fu_wac_device_to_string (FuDevice *device, guint idt, GString *str)
 		g_autofree gchar *tmp = g_strdup_printf ("0x%04x", (guint) self->configuration);
 		fu_common_string_append_kv (str, idt, "Configuration", tmp);
 	}
-	for (guint i = 0; i < self->flash_descriptors->len; i++) {
-		FuWacFlashDescriptor *fd = g_ptr_array_index (self->flash_descriptors, i);
-		g_autofree gchar *title = g_strdup_printf ("FlashDescriptor%02u", i);
-		fu_common_string_append_kv (str, idt, title, NULL);
-		fu_wac_device_flash_descriptor_to_string (fd, idt + 1, str);
+	if (g_getenv ("FWUPD_WACOM_USB_VERBOSE") != NULL) {
+		for (guint i = 0; i < self->flash_descriptors->len; i++) {
+			FuWacFlashDescriptor *fd = g_ptr_array_index (self->flash_descriptors, i);
+			g_autofree gchar *title = g_strdup_printf ("FlashDescriptor%02u", i);
+			fu_common_string_append_kv (str, idt, title, NULL);
+			fu_wac_device_flash_descriptor_to_string (fd, idt + 1, str);
+		}
 	}
 	status_str = fu_wac_device_status_to_string (self->status_word);
 	fu_common_string_append_kv (str, idt, "Status", status_str->str);
@@ -258,7 +260,8 @@ fu_wac_device_ensure_checksums (FuWacDevice *self, GError **error)
 	g_array_set_size (self->checksums, 0);
 	for (guint i = 0; i < self->nr_flash_blocks; i++) {
 		guint32 csum = fu_common_read_uint32 (buf + 5 + (i * 4), G_LITTLE_ENDIAN);
-		g_debug ("checksum block %02u: 0x%08x", i, (guint) csum);
+		if (g_getenv ("FWUPD_WACOM_USB_VERBOSE") != NULL)
+			g_debug ("checksum block %02u: 0x%08x", i, (guint) csum);
 		g_array_append_val (self->checksums, csum);
 	}
 	g_debug ("added %u checksums", self->flash_descriptors->len);
@@ -459,6 +462,10 @@ fu_wac_device_write_firmware (FuDevice *device,
 	g_autoptr(FuFirmwareImage) img = NULL;
 	g_autoptr(GHashTable) fd_blobs = NULL;
 
+	/* get current selected device */
+	if (!fu_wac_device_ensure_firmware_index (self, error))
+		return FALSE;
+
 	/* use the correct image from the firmware */
 	img = fu_firmware_get_image_by_idx (firmware, self->firmware_index == 1 ? 1 : 0, error);
 	if (img == NULL)
@@ -469,10 +476,6 @@ fu_wac_device_write_firmware (FuDevice *device,
 	if (!fu_wac_device_switch_to_flash_loader (self, error))
 		return FALSE;
 
-	/* get current selected device */
-	if (!fu_wac_device_ensure_firmware_index (self, error))
-		return FALSE;
-
 	/* get firmware parameters (page sz and transfer sz) */
 	if (!fu_wac_device_ensure_parameters (self, error))
 		return FALSE;
@@ -563,7 +566,8 @@ fu_wac_device_write_firmware (FuDevice *device,
 
 		/* calculate expected checksum and save to device RAM */
 		csum_local[i] = fu_wac_calculate_checksum32le_bytes (blob_block);
-		g_debug ("block checksum %02u: 0x%08x", i, csum_local[i]);
+		if (g_getenv ("FWUPD_WACOM_USB_VERBOSE") != NULL)
+			g_debug ("block checksum %02u: 0x%08x", i, csum_local[i]);
 		if (!fu_wac_device_set_checksum_of_block (self, i, csum_local[i], error))
 			return FALSE;
 
@@ -571,6 +575,15 @@ fu_wac_device_write_firmware (FuDevice *device,
 		fu_device_set_progress_full (device, blocks_done++, blocks_total);
 	}
 
+	/* check at least one block was written */
+	if (blocks_done == 0) {
+		g_set_error (error,
+			     FWUPD_ERROR,
+			     FWUPD_ERROR_INTERNAL,
+			     "empty firmware image or all blocks write-protected");
+		return FALSE;
+	}
+
 	/* calculate CRC inside device */
 	for (guint16 i = 0; i < self->flash_descriptors->len; i++) {
 		if (!fu_wac_device_calculate_checksum_of_block (self, i, error))
@@ -610,7 +623,8 @@ fu_wac_device_write_firmware (FuDevice *device,
 				     (guint) csum_rom, (guint) csum_local[i]);
 			return FALSE;
 		}
-		g_debug ("matched checksum at block %u of 0x%08x", i, csum_rom);
+		if (g_getenv ("FWUPD_WACOM_USB_VERBOSE") != NULL)
+			g_debug ("matched checksum at block %u of 0x%08x", i, csum_rom);
 	}
 
 	/* update device progress */
@@ -634,6 +648,7 @@ fu_wac_device_add_modules_bluetooth (FuWacDevice *self, GError **error)
 	g_autoptr(FuWacModule) module = NULL;
 	guint8 buf[] = { [0] = FU_WAC_REPORT_ID_GET_FIRMWARE_VERSION_BLUETOOTH,
 			 [1 ... 14] = 0xff };
+	guint16 fw_ver;
 
 	buf[0] = FU_WAC_REPORT_ID_GET_FIRMWARE_VERSION_BLUETOOTH;
 	if (!fu_wac_device_get_feature_report (self, buf, sizeof(buf),
@@ -643,14 +658,19 @@ fu_wac_device_add_modules_bluetooth (FuWacDevice *self, GError **error)
 		return FALSE;
 	}
 
+	if (!fu_common_read_uint16_safe (buf, sizeof(buf), 1, &fw_ver,
+					 G_LITTLE_ENDIAN, error))
+		return FALSE;
+	version = fu_common_version_from_uint16 (fw_ver, FWUPD_VERSION_FORMAT_BCD);
+
 	/* success */
 	name = g_strdup_printf ("%s [Legacy Bluetooth Module]",
 				fu_device_get_name (FU_DEVICE (self)));
-	version = g_strdup_printf ("%x.%x", (guint) buf[2], (guint) buf[1]);
 	module = fu_wac_module_bluetooth_new (usb_device);
 	fu_device_add_child (FU_DEVICE (self), FU_DEVICE (module));
 	fu_device_set_name (FU_DEVICE (module), name);
 	fu_device_set_version (FU_DEVICE (module), version);
+	fu_device_set_version_raw (FU_DEVICE (module), fw_ver);
 	return TRUE;
 }
 
@@ -673,6 +693,7 @@ fu_wac_device_add_modules (FuWacDevice *self, GError **error)
 	g_autofree gchar *version_bootloader = NULL;
 	guint8 buf[] = { [0] = FU_WAC_REPORT_ID_FW_DESCRIPTOR,
 			 [1 ... 31] = 0xff };
+	guint16 boot_ver;
 
 	if (!fu_wac_device_get_feature_report (self, buf, sizeof(buf),
 					       FU_HID_DEVICE_FLAG_NONE,
@@ -700,8 +721,12 @@ fu_wac_device_add_modules (FuWacDevice *self, GError **error)
 	}
 
 	/* bootloader version */
-	version_bootloader = g_strdup_printf ("%u.%u", buf[1], buf[2]);
+	if (!fu_common_read_uint16_safe (buf, sizeof(buf), 1, &boot_ver,
+					 G_BIG_ENDIAN, error))
+		return FALSE;
+	version_bootloader = fu_common_version_from_uint16 (boot_ver, FWUPD_VERSION_FORMAT_BCD);
 	fu_device_set_version_bootloader (FU_DEVICE (self), version_bootloader);
+	fu_device_set_version_bootloader_raw (FU_DEVICE (self), boot_ver);
 
 	/* get versions of each submodule */
 	for (guint8 i = 0; i < buf[3]; i++) {
@@ -709,9 +734,12 @@ fu_wac_device_add_modules (FuWacDevice *self, GError **error)
 		g_autofree gchar *name = NULL;
 		g_autofree gchar *version = NULL;
 		g_autoptr(FuWacModule) module = NULL;
+		guint16 ver;
 
-		/* version number is decimal */
-		version = g_strdup_printf ("%u.%u", buf[(i * 4) + 5], buf[(i * 4) + 6]);
+		if (!fu_common_read_uint16_safe (buf, sizeof(buf), (i * 4) + 5,
+						 &ver, G_BIG_ENDIAN, error))
+			return FALSE;
+		version = fu_common_version_from_uint16 (ver, FWUPD_VERSION_FORMAT_BCD);
 
 		switch (fw_type) {
 		case FU_WAC_MODULE_FW_TYPE_TOUCH:
@@ -721,6 +749,7 @@ fu_wac_device_add_modules (FuWacDevice *self, GError **error)
 			fu_device_add_child (FU_DEVICE (self), FU_DEVICE (module));
 			fu_device_set_name (FU_DEVICE (module), name);
 			fu_device_set_version (FU_DEVICE (module), version);
+			fu_device_set_version_raw (FU_DEVICE (module), ver);
 			break;
 		case FU_WAC_MODULE_FW_TYPE_BLUETOOTH:
 			module = fu_wac_module_bluetooth_new (usb_device);
@@ -729,9 +758,11 @@ fu_wac_device_add_modules (FuWacDevice *self, GError **error)
 			fu_device_add_child (FU_DEVICE (self), FU_DEVICE (module));
 			fu_device_set_name (FU_DEVICE (module), name);
 			fu_device_set_version (FU_DEVICE (module), version);
+			fu_device_set_version_raw (FU_DEVICE (module), ver);
 			break;
 		case FU_WAC_MODULE_FW_TYPE_MAIN:
 			fu_device_set_version (FU_DEVICE (self), version);
+			fu_device_set_version_raw (FU_DEVICE (self), ver);
 			break;
 		default:
 			g_warning ("unknown submodule type 0x%0x", fw_type);
@@ -805,7 +836,7 @@ fu_wac_device_init (FuWacDevice *self)
 	fu_device_add_protocol (FU_DEVICE (self), "com.wacom.usb");
 	fu_device_add_icon (FU_DEVICE (self), "input-tablet");
 	fu_device_add_flag (FU_DEVICE (self), FWUPD_DEVICE_FLAG_UPDATABLE);
-	fu_device_set_version_format (FU_DEVICE (self), FWUPD_VERSION_FORMAT_PAIR);
+	fu_device_set_version_format (FU_DEVICE (self), FWUPD_VERSION_FORMAT_BCD);
 	fu_device_set_install_duration (FU_DEVICE (self), 10);
 	fu_device_set_remove_delay (FU_DEVICE (self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 }
