@@ -1136,12 +1136,12 @@ fu_util_device_to_string (FwupdDevice *dev, guint idt)
 	GPtrArray *guids = fwupd_device_get_guids (dev);
 	GPtrArray *vendor_ids = fwupd_device_get_vendor_ids (dev);
 	GPtrArray *instance_ids = fwupd_device_get_instance_ids (dev);
-	GString *str = g_string_new (NULL);
 	const gchar *tmp;
 	const gchar *tmp2;
 	guint64 flags = fwupd_device_get_flags (dev);
 	guint64 modified = fwupd_device_get_modified (dev);
 	g_autoptr(GHashTable) ids = NULL;
+	g_autoptr(GString) str = g_string_new (NULL);
 
 	/* some fields are intentionally not included and are only shown in --verbose */
 	if (g_getenv ("FWUPD_VERBOSE") != NULL) {
@@ -1205,7 +1205,7 @@ fu_util_device_to_string (FwupdDevice *dev, guint idt)
 	/* vendor */
 	tmp = fwupd_device_get_vendor (dev);
 	if (tmp != NULL && vendor_ids->len > 0) {
-		g_autofree gchar *strv = fu_common_strjoin_array ("|", vendor_ids);
+		g_autofree gchar *strv = fu_common_strjoin_array (", ", vendor_ids);
 		g_autofree gchar *both = g_strdup_printf ("%s (%s)", tmp, strv);
 		/* TRANSLATORS: manufacturer of hardware */
 		fu_common_string_append_kv (str, idt + 1, _("Vendor"), both);
@@ -1318,7 +1318,7 @@ fu_util_device_to_string (FwupdDevice *dev, guint idt)
 		}
 	}
 
-	return g_string_free (str, FALSE);
+	return g_string_free (g_steal_pointer (&str), FALSE);
 }
 
 const gchar *
@@ -1346,7 +1346,7 @@ fu_util_plugin_flag_to_string (FwupdPluginFlags plugin_flag)
 	}
 	if (plugin_flag == FWUPD_PLUGIN_FLAG_LEGACY_BIOS) {
 		/* TRANSLATORS: system is not booted in UEFI mode */
-		return _("Firmware can not be updated in legacy BIOS mode");
+		return _("UEFI firmware can not be updated in legacy BIOS mode");
 	}
 	if (plugin_flag == FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED) {
 		/* TRANSLATORS: capsule updates are an optional BIOS feature */
